@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -67,7 +67,7 @@ def logfile_parser():
     request_file = menu.options.logfile
 
   if not os.path.exists(request_file):
-    err_msg = "It seems that the '" + request_file + "' file, does not exist."
+    err_msg = "It seems the '" + request_file + "' file, does not exist."
     settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
     raise SystemExit()
 
@@ -81,7 +81,7 @@ def logfile_parser():
     if menu.options.requestfile or menu.options.logfile:
       c = 1
       request_headers = []
-      request_lines = request.split("\n")
+      request_lines = request.split(settings.END_LINE.LF)
       while c < len(request_lines) and len(request_lines[c]) > 0:
         x = request_lines[c].find(':')
         header_name = request_lines[c][:x].title()
@@ -89,12 +89,12 @@ def logfile_parser():
         if menu.options.header:
           request_headers.append(menu.options.header)
         elif menu.options.headers:
-          request_headers.extend(menu.options.headers.split("\\n"))
+          request_headers.extend(menu.options.headers.split(settings.END_LINE.ESCAPED_LF))
         request_headers.append(header_name + ":" + header_value)
         c += 1
       c += 1  
       menu.options.data = "".join(request_lines[c:] if c < len(request_lines) else "")
-      settings.RAW_HTTP_HEADERS = '\\n'.join(request_headers)
+      settings.RAW_HTTP_HEADERS = settings.END_LINE.ESCAPED_LF.join(request_headers)
 
   except IOError as err_msg:
     error_msg = "The '" + request_file + "' "
@@ -107,13 +107,21 @@ def logfile_parser():
   if len(re.findall(pattern, request)) > 1:
     single_request = multi_requests()
 
+  # Safely determine HTTP method
   if len(settings.HTTP_METHOD) == 0:
-    http_method = request.strip().splitlines()[0].split()[0]
+    lines = request.strip().splitlines()
+    if lines and len(lines[0].split()) >= 1:
+      http_method = lines[0].split()[0]
+    else:
+      # fallback to default method if malformed/empty
+      http_method = settings.HTTPMETHOD.GET
     settings.HTTP_METHOD = http_method
   else:
     http_method = settings.HTTP_METHOD
 
-  request_url = re.findall(r"" + " (.*)" + " HTTP/", request)
+  # Safely extract request URL
+  match = re.search(r"\s(.*?)\sHTTP/", request or "")
+  request_url = match.group(1) if match else ""
 
   if not request_url:
     invalid_data(request_file)
@@ -124,7 +132,7 @@ def logfile_parser():
   scheme = "http://"
 
   for line in request_headers:
-    if re.findall(r"" + settings.HOST + ":" + " (.*)", line):
+    if re.findall(r"^" + settings.HOST + ":" + " (.*)", line):
       menu.options.host = "".join([str(i) for i in re.findall(r"" + settings.HOST + ":" + " (.*)", line)])
     # User-Agent Header
     if re.findall(r"" + settings.USER_AGENT + ":" + " (.*)", line):
@@ -142,7 +150,17 @@ def logfile_parser():
       if auth_provided:
         menu.options.auth_type = auth_provided[0].lower()
         if menu.options.auth_type.lower() == settings.AUTH_TYPE.BASIC:
-          menu.options.auth_cred = base64.b64decode(auth_provided[1]).decode()
+          # menu.options.auth_cred = base64.b64decode(auth_provided[1]).decode()
+          try:
+            # Add base64 padding if missing
+            b64_string = auth_provided[1]
+            b64_string += '=' * (-len(b64_string) % 4)
+            menu.options.auth_cred = base64.b64decode(b64_string).decode()
+          except (binascii.Error, UnicodeDecodeError) as e:
+            err_msg = "Invalid base64-encoded credentials provided in Authorization header: " + format(str(e))
+            settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+            raise SystemExit()
+
         elif menu.options.auth_type.lower() == settings.AUTH_TYPE.DIGEST:
           if not menu.options.auth_cred:
             err_msg = "Use the '--auth-cred' option to provide a valid pair of "
@@ -155,7 +173,7 @@ def logfile_parser():
       match = re.findall(r"(.*): (.*)", line)
       match = "".join([str(i) for i in match]).replace("', '",":")
       match = match.replace("('", "")
-      match = match.replace("')","\\n")
+      match = match.replace("')",settings.END_LINE.ESCAPED_LF)
       # Ignore some header.
       if settings.CONTENT_LENGTH or settings.ACCEPT_ENCODING in match:
         extra_headers = extra_headers
