@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -31,6 +31,11 @@ Find the URL directory.
 def injection_output(url, OUTPUT_TEXTFILE, timesec, technique):
   return injector.injection_output(url, OUTPUT_TEXTFILE, timesec, technique)
 
+"""
+"""
+def select_output_filename(technique, tmp_path, TAG):
+  return injector.select_output_filename(technique, tmp_path, TAG)
+
 """
 Command execution results.
 """
