@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -93,47 +93,44 @@ def defined_http_headers(url):
       settings.print_data_to_stdout(settings.print_debug_msg(debug_msg)) 
 
   def user_agent():
-    # Check if defined "--mobile" option.
-    if menu.options.mobile:
-      if ((menu.options.agent != settings.DEFAULT_USER_AGENT) and not menu.options.requestfile) or menu.options.random_agent:
-        if not settings.MULTI_TARGETS or not settings.STDIN_PARSING:
-          err_msg = "The switch '--mobile' is incompatible with option '--user-agent' or switch '--random-agent'."
-          settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
-          raise SystemExit()
-      else:
-        menu.options.agent = checks.mobile_user_agents()
-
-    # Check if defined "--random-agent" option.
-    if menu.options.random_agent:
-      if ((menu.options.agent != settings.DEFAULT_USER_AGENT) and not menu.options.requestfile) or menu.options.mobile:
-        if not settings.MULTI_TARGETS or not settings.STDIN_PARSING:
-          err_msg = "The switch '--random-agent' is incompatible with option '--user-agent' or switch '--mobile'."
-          settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
-          raise SystemExit()
-      else:
-        if settings.VERBOSITY_LEVEL != 0:
-          debug_msg = "Fetching random HTTP User-Agent header. "
-          settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
-        else:
-          pass
-        try:
-          menu.options.agent = random.choice(settings.USER_AGENT_LIST)
-          info_msg = "The fetched random HTTP User-Agent header value is '" + menu.options.agent + "'."
-          settings.print_data_to_stdout(settings.print_info_msg(info_msg))
-        except:
-          settings.print_data_to_stdout(settings.SINGLE_WHITESPACE)
+    # Determine which option is enabled
+    mobile_agent = menu.options.mobile
+    random_agent = menu.options.random_agent
+    custom_agent = menu.options.agent != settings.DEFAULT_USER_AGENT and not menu.options.requestfile
 
+    # Final debug message
     if settings.VERBOSITY_LEVEL != 0:
       debug_msg = "Setting the HTTP User-Agent header."
       settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
 
+    # Combined check for incompatible combinations
+    if (mobile_agent and (custom_agent or random_agent)) or (random_agent and (custom_agent or mobile_agent)):
+      if not any([settings.MULTI_TARGETS, settings.STDIN_PARSING]):
+        if mobile_agent:
+          err_msg = "The switch '--mobile' is incompatible with option '--user-agent' or switch '--random-agent'."
+        else:
+          err_msg = "The switch '--random-agent' is incompatible with option '--user-agent' or switch '--mobile'."
+        settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+        raise SystemExit()
+
+    # Set the User-Agent
+    if mobile_agent:
+      menu.options.agent = checks.mobile_user_agents()
+    elif random_agent:
+      if settings.VERBOSITY_LEVEL != 0:
+        debug_msg = "Fetching random HTTP User-Agent header. "
+        settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
+      user_agents = common.load_list_from_file(settings.USER_AGENT_LIST, "user-agent list")
+      menu.options.agent = random.choice(user_agents)
+      info_msg = "The fetched random HTTP User-Agent header value is '" + menu.options.agent + "'."
+      settings.print_data_to_stdout(settings.print_info_msg(info_msg))
+
   extra_headers()
   cookie()
   referer(url)
   host(url)
   user_agent()
 
-
 """
 Examine the request
 """
@@ -192,61 +189,87 @@ def check_internet(url):
 The init (URL) request.
 """
 def init_request(url, http_request_method):
-  # Number of seconds to wait before timeout connection
+
+  def perform_init_request(url, http_request_method):
+    if settings.USER_DEFINED_POST_DATA:
+      request = _urllib.request.Request(url, settings.USER_DEFINED_POST_DATA.encode(), method=http_request_method)
+    else:
+      request = _urllib.request.Request(url, method=http_request_method)
+    headers.do_check(request)
+    return request
+
   if settings.VERBOSITY_LEVEL != 0:
     debug_msg = "Setting the HTTP timeout."
     settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
   if menu.options.timeout:
     settings.TIMEOUT = menu.options.timeout
+
+  if menu.options.proxy: 
+    proxy.do_check()
+
+  if menu.options.auth_cred and menu.options.auth_type and settings.VERBOSITY_LEVEL != 0 :
+    debug_msg = "Setting the HTTP authentication type and credentials."
+    settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
+
+  _ = None
+  response = None
+  redirect_url = None
+
+  try:
+    if settings.VERBOSITY_LEVEL != 0:
+      debug_msg = "Creating " + str(settings.SCHEME).upper() + " requests opener object."
+      settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
+    opener = _urllib.request.build_opener(redirection.RedirectHandler())
+    request = perform_init_request(url, http_request_method)
+    response = opener.open(request, timeout=settings.TIMEOUT)
+    if response.geturl() != url:
+      redirect_url = response.geturl()
+      
+  except _urllib.error.HTTPError as e:
+    _ = True
+    redirect_url = e.geturl()
+
+  except Exception as err_msg:
+    requests.request_failed(err_msg)
+
+  if redirect_url and redirect_url != url:
+    redirect_url = redirection.do_check(request, url, redirect_url, http_request_method)
+    if redirect_url is not None and settings.FOLLOW_REDIRECT:
+      if _:
+        url = redirect_url
+      request = perform_init_request(redirect_url, http_request_method)
+
   # Define HTTP headers
   defined_http_headers(url)
   # Check the internet connection (--check-internet switch).
   if menu.options.check_internet:
     check_internet(url)
-  # Check if defined POST data
-  if settings.USER_DEFINED_POST_DATA:
-    request = _urllib.request.Request(url, settings.USER_DEFINED_POST_DATA.encode(), method=http_request_method)
-  else:
-    request = _urllib.request.Request(url, method=http_request_method)
-  headers.do_check(request)
-  # Used a valid pair of valid credentials
-  if menu.options.auth_cred and menu.options.auth_type and settings.VERBOSITY_LEVEL != 0 :
-    debug_msg = "Setting the HTTP authentication type and credentials."
-    settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
-  if menu.options.proxy: 
-    proxy.do_check()
-  if settings.VERBOSITY_LEVEL != 0:
-    debug_msg = "Creating " + str(settings.SCHEME).upper() + " requests opener object."
-    settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
-  settings.CUSTOM_INJECTION_MARKER = checks.custom_injection_marker_character(url, http_request_method)
-  # Check connection(s)
+
   checks.check_connection(url)
-  return request
+  settings.CUSTOM_INJECTION_MARKER = checks.custom_injection_marker_character(url, http_request_method)
+
+  return request, url
   
 """
 Get the URL response.
 """
 def url_response(url, http_request_method):
-  # Check if http / https
-  url = checks.check_http_s(url)
-  settings.TARGET_URL = _urllib.parse.urlparse(url).hostname
-  if settings.MULTI_TARGETS or settings.CRAWLING:
-    settings.TOR_CHECK_AGAIN = False
-    # initiate total of requests
-    settings.TOTAL_OF_REQUESTS = 0
-  request = init_request(url, http_request_method)
   if settings.CHECK_INTERNET:
     settings.CHECK_INTERNET = False
   if settings.INIT_TEST == True:
     info_msg = "Testing connection to the target URL. "
     settings.print_data_to_stdout(settings.print_bold_info_msg(info_msg))
+
+  # Check if http / https
+  url = checks.check_http_s(url)
+  request, url = init_request(url, http_request_method)
   response = examine_request(request, url)
-  # Check for URL redirection
-  if type(response) is not bool and settings.FOLLOW_REDIRECT and response is not None:
-    if response.geturl() != url:
-      redirect_url = redirection.do_check(request, url, response.geturl())
-      if redirect_url is not None:
-        url = redirect_url
+  settings.TARGET_URL = _urllib.parse.urlparse(url).hostname
+  if settings.MULTI_TARGETS or settings.CRAWLING:
+    settings.TOR_CHECK_AGAIN = False
+    # initiate total of requests
+    settings.TOTAL_OF_REQUESTS = 0
+
   if not menu.options.skip_waf:
     settings.COOKIE_INJECTION = None
     settings.WAF_DETECTION_PHASE = True
@@ -256,36 +279,34 @@ def url_response(url, http_request_method):
   return response, url
 
 """
-Initializing injection status.
+Initialize injection-related settings and state.
 """
 def init_injection(url):
   if settings.VERBOSITY_LEVEL != 0:
     debug_msg = "Initializing the knowledge base."
     settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
-  # Initiate heuristic checks.
-  if not settings.FOLLOW_REDIRECT:
-    settings.FOLLOW_REDIRECT = True
-  if settings.SKIP_CODE_INJECTIONS:
-    settings.SKIP_CODE_INJECTIONS = False
-  if settings.SKIP_COMMAND_INJECTIONS:
-    settings.SKIP_COMMAND_INJECTIONS = False
-  # Initiate injection checker.
-  if settings.INJECTION_CHECKER:
-    settings.INJECTION_CHECKER = False
-  # Initiate exploitation techniques states.
-  if settings.INJECTION_CHECKER:
-    settings.CLASSIC_STATE = False
-  if settings.EVAL_BASED_STATE:
-    settings.EVAL_BASED_STATE = False
-  if settings.TIME_BASED_STATE:
-    settings.TIME_BASED_STATE = False
-  if settings.FILE_BASED_STATE:
-    settings.FILE_BASED_STATE = False
-  if settings.TEMPFILE_BASED_STATE:
-    settings.TEMPFILE_BASED_STATE = False
-  if settings.TIME_RELATIVE_ATTACK:
-    settings.TIME_RELATIVE_ATTACK = False
 
+  # Ensure redirection is followed and core injection paths are enabled
+  settings.FOLLOW_REDIRECT = True
+  settings.SKIP_CODE_INJECTIONS = False
+  settings.SKIP_COMMAND_INJECTIONS = False
+
+  # Reset injection checker and technique flags
+  settings.INJECTION_CHECKER = False
+  settings.CLASSIC_STATE = False
+  settings.EVAL_BASED_STATE = False
+  settings.TIME_BASED_STATE = False
+  settings.FILE_BASED_STATE = False
+  settings.TEMPFILE_BASED_STATE = False
+  settings.TIME_RELATED_ATTACK = False
+
+  # Reset custom and temporary settings
+  settings.TESTED_PARAMETERS_LIST = []
+  settings.METHODS_WITH_NON_LISTED_PARAMS = []
+  settings.SKIP_NON_CUSTOM_PARAMS = None
+  settings.CUSTOM_INJECTION_MARKER = None
+  settings.CUSTOM_FILENAME = ""
+  
 """
 Using 'stdin' for parsing targets.
 """
@@ -408,7 +429,7 @@ def main(filename, url, http_request_method):
 
     # Check if defined character used for splitting cookie values.
     if menu.options.cdel:
-     settings.COOKIE_DELIMITER = menu.options.cdel
+     settings.COOKIE_PARAM_DELIMITER = menu.options.cdel
 
     if menu.options.tech and settings.USER_APPLIED_TECHNIQUE != None:
       settings.USER_APPLIED_TECHNIQUE = True
@@ -420,6 +441,7 @@ def main(filename, url, http_request_method):
       else:
         menu.options.tech = ''.join([str(x) for x in settings.AVAILABLE_TECHNIQUES])
 
+    menu.options.tech = menu.options.tech.lower()
     # Check for skipping injection techniques.
     if menu.options.skip_tech:
       # Convert injection technique(s) to lowercase
@@ -500,8 +522,6 @@ def main(filename, url, http_request_method):
                                                    password=password
                                                    )
       try:
-        # Check for CGI scripts on url
-        checks.check_CGI_scripts(url)
         # Check if defined "--file-upload" option.
         if menu.options.file_upload:
           menu.options.file_upload = os.path.abspath(menu.options.file_upload)
@@ -515,8 +535,9 @@ def main(filename, url, http_request_method):
             settings.print_data_to_stdout(settings.print_critical_msg(str(err_msg.reason) + "."))
             raise SystemExit()
         try:
-          info_msg = "Performing identification (passive) tests to the target URL."
+          info_msg = "Performing heuristic (passive) tests on the target URL."
           settings.print_data_to_stdout(settings.print_info_msg(info_msg))
+          requests.is_url_content_stable(url)
           # Webpage encoding detection.
           requests.encoding_detection(response)
           # Procedure for target server identification.
@@ -670,7 +691,7 @@ try:
       else:
         settings.DEFAULT_CODEC  = menu.options.codec.lower()
 
-    if menu.options.header and len(menu.options.header.split("\\n"))> 1:
+    if menu.options.header and len(menu.options.header.split(settings.END_LINE.ESCAPED_LF))> 1:
         warn_msg = "Due to multiple provided HTTP headers, swithing '--header' to '--headers'."
         settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
 
@@ -812,7 +833,7 @@ try:
     # Check if defined "--timesec" option.
     if menu.options.timesec != 0:
       settings.TIMESEC = menu.options.timesec
-
+    
     if menu.options.tor:
       settings.TIMESEC = settings.TIMESEC * 2
       warn_msg = "Increasing default value for option '--time-sec' to"
@@ -886,13 +907,13 @@ try:
       settings.USER_DEFINED_POST_DATA = menu.options.data
       # Check if defined character used for splitting parameter values.
       if menu.options.pdel and menu.options.pdel in settings.USER_DEFINED_POST_DATA:
-        settings.PARAMETER_DELIMITER = menu.options.pdel
+        settings.POST_DATA_PARAM_DELIMITER = menu.options.pdel
     else:
       # Check if defined character used for splitting parameter values.
       if menu.options.pdel and menu.options.pdel in url:
-        settings.PARAMETER_DELIMITER = menu.options.pdel
+        settings.URL_PARAM_DELIMITER = menu.options.pdel
+        
     http_request_method  = checks.check_http_method(url)
-
     if not settings.STDIN_PARSING and not menu.options.bulkfile and not settings.CRAWLING:
       if os_checks_num == 0:
         settings.INIT_TEST = True
@@ -911,12 +932,12 @@ try:
           settings.print_data_to_stdout(settings.print_info_msg(info_msg))
           
         if not os.path.exists(bulkfile):
-          err_msg = "It seems that the '" + os.path.split(bulkfile)[1] + "' file, does not exist."
+          err_msg = "It seems the '" + os.path.split(bulkfile)[1] + "' file, does not exist."
           settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
           raise SystemExit()
 
         elif os.stat(bulkfile).st_size == 0:
-          err_msg = "It seems that the '" + os.path.split(bulkfile)[1] + "' file, is empty."
+          err_msg = "It seems the '" + os.path.split(bulkfile)[1] + "' file, is empty."
           settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
           raise SystemExit()
 
@@ -996,7 +1017,7 @@ try:
             perform_check = True
             while True:
               settings.print_data_to_stdout(settings.print_message("[" + str(url_num) + "/" + str(len(clean_output_href)) + "] URL - " + http_request_method + " " + url))
-              message = "Do you want to use URL #" + str(url_num) + " to perform tests? [Y/n] > "
+              message = "Do you want to use URL #" + str(url_num) + " for testing? [Y/n] > "
               next_url = common.read_input(message, default="Y", check_batch=True)
               if next_url in settings.CHOICE_YES:
                 info_msg = "Testing URL '" + url + "'."
