@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,6 +33,6 @@ def load_modules(url, http_request_method, filename):
       # The shellshock handler
       shellshock.shellshock_handler(url, http_request_method, filename)
     except ImportError as err_msg:
-      settings.print_data_to_stdout("\n" + settings.print_critical_msg(err_msg))
+      settings.print_data_to_stdout(settings.END_LINE.LF + settings.print_critical_msg(err_msg))
       raise SystemExit()
     raise SystemExit()
\ No newline at end of file
