@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -42,6 +42,21 @@ from src.core.injections.controller import checks
 from src.thirdparty.colorama import Fore, Back, Style, init
 from src.thirdparty.six.moves import urllib as _urllib
 
+"""
+Encoding non-ASCII characters (in URL path and query).
+"""
+def encode_non_ascii_url(request):
+  url = request.get_full_url()
+  parts = _urllib.parse.urlsplit(url)
+  # Encode path, preserving '/', '*', and '%' to avoid over-encoding
+  path = _urllib.parse.quote(parts.path, safe=settings.SAFE_PATH)
+  # Encode query string, preserving delimiters and configured parameter delimiter
+  query = _urllib.parse.quote(parts.query, safe=settings.SAFE_QUERY + settings.URL_PARAM_DELIMITER)
+  # Reconstruct the full URL with encoded path and query
+  request.full_url = _urllib.parse.urlunsplit((parts.scheme, parts.netloc, path, query, parts.fragment))
+
+  return request
+  
 """
 Checking the HTTP response content.
 """
@@ -53,30 +68,34 @@ def http_response_content(content):
     settings.print_data_to_stdout(settings.print_http_response_content(content))
   if menu.options.traffic_file:
     logs.log_traffic(content)
-    logs.log_traffic("\n\n" + "#" * 77 + "\n\n")
+    logs.log_traffic(settings.END_LINE.LF * 2 + "#" * 77 + settings.END_LINE.LF * 2)
 
 """
 Checking the HTTP response headers.
 """
 def http_response(headers, code):
-  response_http_headers = str(headers).split("\n")
+  response_http_headers = str(headers).split(settings.END_LINE.LF)
   for header in response_http_headers:
     if len(header) > 1:
       if settings.VERBOSITY_LEVEL >= 3:
         settings.print_data_to_stdout(settings.print_traffic(header))
       if menu.options.traffic_file:
-        logs.log_traffic("\n" + header)
+        logs.log_traffic(settings.END_LINE.LF + header)
   if menu.options.traffic_file:
-    logs.log_traffic("\n\n")
+    logs.log_traffic(settings.END_LINE.LF * 2)
 
 """
 Print HTTP response headers / Body.
 """
 def print_http_response(response_headers, code, page):
-  if int(code) in settings.ABORT_CODE:
-    err_msg = "Aborting due to detected HTTP code '" + str(code) + "'. "
-    settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
-    raise SystemExit()
+  try:
+    if int(code) in settings.ABORT_CODE:
+      err_msg = "Aborting due to detected HTTP code '" + str(code) + "'. "
+      settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+      raise SystemExit()
+  except (ValueError, TypeError):
+    warn_msg = "Skipping abort check due to invalid (or missing) HTTP response code '" + str(code) + "'"
+    settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
 
   if settings.VERBOSITY_LEVEL >= 3 or menu.options.traffic_file:
     if settings.VERBOSITY_LEVEL >= 3:
@@ -84,7 +103,7 @@ def print_http_response(response_headers, code, page):
       settings.print_data_to_stdout(settings.print_response_msg(resp_msg))
     if menu.options.traffic_file:
       resp_msg = "HTTP response [#" + str(settings.TOTAL_OF_REQUESTS) + "] (" + str(code) + "):"
-      logs.log_traffic("\n" + resp_msg)
+      logs.log_traffic(settings.END_LINE.LF + resp_msg)
     http_response(response_headers, code)
   if settings.VERBOSITY_LEVEL >= 4 or menu.options.traffic_file:
     if settings.VERBOSITY_LEVEL >= 4:
@@ -105,10 +124,14 @@ def check_http_traffic(request):
   else:
     http_client = _http_client.HTTPConnection
 
+  if menu.options.http10:
+    _http_client.HTTPConnection._http_vsn = 10
+    _http_client.HTTPConnection._http_vsn_str = 'HTTP/1.0'
+
   class connection(http_client):
     def send(self, req):
       headers = req.decode()
-      request_http_headers = str(headers).split("\r\n")
+      request_http_headers = str(headers).split(settings.END_LINE.CRLF)
       unique_request_http_headers = []
       [unique_request_http_headers.append(item) for item in request_http_headers if item not in unique_request_http_headers]
       request_http_headers = [x for x in unique_request_http_headers if x]
@@ -120,7 +143,7 @@ def check_http_traffic(request):
         if settings.VERBOSITY_LEVEL >= 2:
           settings.print_data_to_stdout(settings.print_traffic(header))
         if menu.options.traffic_file:
-          logs.log_traffic("\n" + header)
+          logs.log_traffic(settings.END_LINE.LF + header)
       http_client.send(self, req)
 
   class connection_handler(_urllib.request.HTTPSHandler, _urllib.request.HTTPHandler, object):
@@ -170,6 +193,7 @@ def check_http_traffic(request):
         settings.MULTI_ENCODED_PAYLOAD = []
         menu.options.tamper = settings.USER_APPLIED_TAMPER
     try:
+      request = encode_non_ascii_url(request)
       response = opener.open(request, timeout=settings.TIMEOUT)
       _ = True
       settings.MAX_RETRIES = settings.TOTAL_OF_REQUESTS * 2
@@ -190,7 +214,7 @@ def check_http_traffic(request):
     except AttributeError:
       raise SystemExit()
 
-    except _urllib.error.HTTPError as err_msg:
+    except (_urllib.error.HTTPError, _urllib.error.URLError) as err_msg:
       if settings.UNAUTHORIZED_ERROR in str(err_msg):
         settings.UNAUTHORIZED = unauthorized = True
         settings.MAX_RETRIES = settings.TOTAL_OF_REQUESTS
@@ -212,12 +236,12 @@ def check_http_traffic(request):
       response = _urllib.request.urlopen(request, timeout=settings.TIMEOUT)
     code = response.getcode()
     response_headers = response.info()
-    page = checks.page_encoding(response, action="encode")
+    page = checks.process_page_content(response, action="encode")
     response_headers[settings.URI_HTTP_HEADER] = response.geturl()
-    response_headers = str(response_headers).strip("\n")
-    # Checks for not declared cookie(s), while server wants to set its own.
+    response_headers = str(response_headers).strip(settings.END_LINE.LF)
+    # Handle server-set cookies.
     if not menu.options.drop_set_cookie:
-      checks.not_declared_cookies(response)
+      checks.handle_server_cookies(response)
     print_http_response(response_headers, code, page)
     # Checks regarding a potential CAPTCHA protection mechanism.
     checks.captcha_check(page)
@@ -228,18 +252,18 @@ def check_http_traffic(request):
 
   # This is useful when handling exotic HTTP errors (i.e requests for authentication).
   except _urllib.error.HTTPError as err:
-    # Checks for not declared cookie(s), while server wants to set its own.
     if not menu.options.drop_set_cookie:
-      checks.not_declared_cookies(err)
+      checks.handle_server_cookies(err)
     try:
-      if err.fp is None:
+      if getattr(err, 'fp', None) is None:
         raise AttributeError
-      page = checks.page_encoding(err, action="encode")
-    except Exception as e:
+      page = checks.process_page_content(err, action="encode")
+    except Exception:
       page = ''
-      
-    print_http_response(err.info(), err.code, page)
-    
+    response_headers = err.info()
+    code = err.code
+    print_http_response(response_headers, code, page)
+
     if (not settings.PERFORM_CRACKING and \
     not settings.IS_JSON and \
     not settings.IS_XML and \
@@ -252,12 +276,14 @@ def check_http_traffic(request):
     if str(err.code).startswith(('3', '4', '5')):
       settings.HTTP_ERROR_CODES_SUM.append(err.code)
       if settings.VERBOSITY_LEVEL >= 2:
-        if len(str(err).split(": ")[1]) == 0:
+        parts = str(err).split(": ")
+        if len(parts) > 1 and len(parts[1]) == 0:
           error_msg = "Non-standard HTTP status code"
       pass
     else:
-      error_msg = str(err).replace(": "," (")
-      if len(str(err).split(": ")[1]) == 0:
+      error_msg = str(err).replace(": ", " (")
+      parts = str(err).split(": ")
+      if len(parts) > 1 and len(parts[1]) == 0:
         err_msg = error_msg + "Non-standard HTTP status code"
       else:
         err_msg = error_msg
@@ -265,11 +291,30 @@ def check_http_traffic(request):
       settings.print_data_to_stdout(settings.print_critical_msg(err_msg + ")."))
       raise SystemExit()
 
+  except _urllib.error.URLError as err:
+    if not menu.options.drop_set_cookie:
+      checks.handle_server_cookies(err)
+    reason = str(getattr(err, 'reason', 'Unknown error'))
+    reason_parts = reason.split(settings.SINGLE_WHITESPACE)
+    if len(reason_parts) > 2:
+      response_headers = settings.SINGLE_WHITESPACE.join(reason_parts[2:]) + "."
+    else:
+      response_headers = reason
+    if not response_headers.endswith("."):
+      response_headers += "."
+    code = ""
+    page = ""
+    print_http_response(response_headers, code, page)
+    settings.print_data_to_stdout(settings.print_critical_msg("URL Error: " + reason))
+    raise SystemExit()
+
 """
 Check for added headers.
 """
 def do_check(request):
 
+  request = encode_non_ascii_url(request)
+  
   # Check if defined any Cookie HTTP header.
   if menu.options.cookie and not settings.COOKIE_INJECTION:
     request.add_header(settings.COOKIE, checks.remove_tags(menu.options.cookie))
@@ -319,14 +364,14 @@ def do_check(request):
     if menu.options.auth_type.lower() == settings.AUTH_TYPE.BEARER:
       request.add_header(settings.AUTHORIZATION, "Bearer " + menu.options.auth_cred.strip())
     elif menu.options.auth_type.lower() == settings.AUTH_TYPE.BASIC:
-      b64_string = encodebytes(menu.options.auth_cred.encode(settings.DEFAULT_CODEC)).decode().replace('\n', '')
+      b64_string = encodebytes(menu.options.auth_cred.encode(settings.DEFAULT_CODEC)).decode().replace(settings.END_LINE.LF, '')
       request.add_header(settings.AUTHORIZATION, "Basic " + b64_string)
     elif menu.options.auth_type.lower() == settings.AUTH_TYPE.DIGEST:
       try:
         url = menu.options.url
         try:
           response = _urllib.request.urlopen(url, timeout=settings.TIMEOUT)
-        except _urllib.error.HTTPError as e:
+        except (_urllib.error.HTTPError, _urllib.error.URLError) as e:
           try:
             authline = e.headers.get('www-authenticate', '')
             authobj = re.match(r'''(\w*)\s+realm=(.*),''',authline).groups()
@@ -341,7 +386,7 @@ def do_check(request):
             result = _urllib.request.urlopen(url, timeout=settings.TIMEOUT)
           except AttributeError:
             pass
-      except _urllib.error.HTTPError as e:
+      except (_urllib.error.HTTPError, _urllib.error.URLError) as e:
         pass
 
   else:
@@ -361,8 +406,8 @@ def do_check(request):
     if ": //" in extra_headers:
       extra_headers = extra_headers.replace(": //" ,"://")
 
-    if "\\n" in extra_headers:
-      extra_headers = extra_headers.split("\\n")
+    if settings.END_LINE.ESCAPED_LF in extra_headers:
+      extra_headers = extra_headers.split(settings.END_LINE.ESCAPED_LF)
       # Remove empty strings and "Content-Length"
       extra_headers = [x for x in extra_headers if settings.CONTENT_LENGTH not in x]
     else:
@@ -398,10 +443,14 @@ def do_check(request):
         if http_header_name not in [settings.ACCEPT, settings.HOST, settings.USER_AGENT, settings.REFERER, settings.COOKIE]:
           if not settings.CUSTOM_HEADER_INJECTION:
             if settings.CUSTOM_INJECTION_MARKER_CHAR in http_header_value:
+              settings.CUSTOM_INJECTION_MARKER = True
               settings.CUSTOM_HEADER_CHECK = http_header_name
-              # settings.CUSTOM_INJECTION_MARKER = True
               
-            if http_header_name in settings.TESTABLE_PARAMETERS_LIST or settings.INJECT_TAG in http_header_value or settings.ASTERISK_MARKER in http_header_value:
+            if settings.CUSTOM_INJECTION_MARKER_CHAR in http_header_value or \
+               http_header_name in settings.TESTABLE_PARAMETERS_LIST or \
+               settings.INJECT_TAG in http_header_value or \
+               settings.ASTERISK_MARKER in http_header_value:
+
               settings.INJECTION_MARKER_LOCATION.CUSTOM_HTTP_HEADERS = True
               settings.CUSTOM_HEADER_CHECK = http_header_name
               if len(http_header_name) != 0 and \
@@ -412,8 +461,21 @@ def do_check(request):
               http_header_value = checks.remove_tags(http_header_value)
               request.add_header(http_header_name, http_header_value)
               
-        if http_header_name not in [settings.HOST, settings.USER_AGENT, settings.REFERER, settings.COOKIE, settings.CUSTOM_HEADER_NAME]:
-          request.add_header(http_header_name, http_header_value)
+        # Normalize for comparison
+        excluded_headers = [
+          settings.HOST,
+          settings.USER_AGENT,
+          settings.REFERER,
+          settings.COOKIE,
+          settings.CUSTOM_HEADER_NAME
+        ]
+        excluded_headers = [h.lower() for h in excluded_headers if h]
+        
+        # Check and apply Title-Case for final header name
+        if http_header_name.lower() not in excluded_headers:
+          normalized_name = '-'.join([part.capitalize() for part in http_header_name.split('-')])
+          request.add_header(normalized_name, http_header_value)
+
       except:
         pass
 
