@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -13,10 +13,12 @@ the Free Software Foundation, either version 3 of the License, or
 For more see the file 'readme/COPYING' for copying permission.
 """
 
+from src.utils import menu
 from src.utils import settings
 
+
 """
-About: Uses backticks instead of "$()" for commands substitution on the generated payloads.
+About: Uses backticks (`) instead of "$()" for commands substitution in a given payload.
 Notes: This tamper script works against Unix-like target(s).
 """
 
@@ -26,9 +28,12 @@ if not settings.TAMPER_SCRIPTS[__tamper__]:
   settings.TAMPER_SCRIPTS[__tamper__] = True
 
 def tamper(payload):
-  settings.TAMPER_SCRIPTS[__tamper__] = True
-  settings.USE_BACKTICKS = True
-  payload = payload.replace("$((", "`expr" + settings.WHITESPACES[0]).replace("))", "`")
+  if not menu.options.alter_shell and not settings.TARGET_OS == settings.OS.WINDOWS:
+    settings.USE_BACKTICKS = True
+    settings.CMD_SUB_PREFIX = settings.CMD_SUB_SUFFIX = "`"
+    payload = payload.replace("${#" + settings.RANDOM_VAR_GENERATOR + "}", 
+                              settings.CMD_SUB_PREFIX + "expr" + settings.WHITESPACES[0] + "length" + settings.WHITESPACES[0] + "\"$" + settings.RANDOM_VAR_GENERATOR + "\"" + settings.CMD_SUB_SUFFIX
+                              )
   return payload
 
 # eof
\ No newline at end of file
