@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,16 +17,19 @@ import random
 from src.utils import settings
 
 """
-About: Adds multiple spaces around OS commands
+About: Adds multiple spaces around operating system commands in a given payload.
 Notes: Useful to bypass very weak and bespoke web application firewalls that has poorly written permissive regular expressions.
 """
 
 __tamper__ = "multiplespaces"
 
+if not settings.TAMPER_SCRIPTS[__tamper__]:
+  settings.TAMPER_SCRIPTS[__tamper__] = True
+
 def tamper(payload):
-  if not (settings.TAMPER_SCRIPTS[__tamper__]):
-    settings.TAMPER_SCRIPTS[__tamper__] = True
+  if settings.TAMPER_SCRIPTS[__tamper__]:
     for i in range(0, len(settings.WHITESPACES)):
       settings.WHITESPACES[i] = settings.WHITESPACES[i] * random.randrange(3, 8)
   return payload
+
 # eof
\ No newline at end of file
