@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ from src.thirdparty.six.moves import urllib as _urllib
 Invalid cmd output
 """
 def invalid_cmd_output(cmd):
-  err_msg = "The execution of '" + cmd + "' command, does not return any output."
+  err_msg = "Execution of the '" + cmd + "' command did not return any output."
   return err_msg
 
 """
@@ -41,20 +41,32 @@ def invalid_option(option):
   err_msg = "'" + option + "' is not a valid answer."
   settings.print_data_to_stdout(settings.print_error_msg(err_msg))
 
+"""
+Reads input from terminal safely
+"""
+def safe_input(message):
+  try:
+    return _input(message)
+  except UnicodeDecodeError as e:
+    return _input(message.encode("utf-8", "ignore").decode("utf-8"))
+  except Exception as err_msg:
+    settings.print_data_to_stdout(settings.print_error_msg(err_msg))
+    return ""
+
 """
 Reads input from terminal
 """
 def read_input(message, default=None, check_batch=True):
   def is_empty():
-    value = _input(settings.print_message(message))
+    value = safe_input(settings.print_message(message))
     if len(value) == 0:
       return default
     else:
       return value
   try:
     value = None
-    if "\n" in message:
-      message += ("\n" if message.count("\n") > 1 else "")
+    if settings.END_LINE.LF in message:
+      message += (settings.END_LINE.LF if message.count(settings.END_LINE.LF) > 1 else "")
     elif len(message) == 0:
       return is_empty()
     if settings.ANSWERS:
@@ -159,7 +171,7 @@ def create_github_issue(err_msg, exc_msg):
 
   key = hashlib.md5(_).hexdigest()[:8]
 
-  bug_report =  "Bug Report: Unhandled exception \"" + str([i for i in exc_msg.split('\n') if i][-1]) + "\" " +  "(#" + key + ")"
+  bug_report =  "Bug Report: Unhandled exception \"" + str([i for i in exc_msg.split(settings.END_LINE.LF) if i][-1]) + "\" " +  "(#" + key + ")"
 
   while True:
     try:
@@ -179,7 +191,7 @@ def create_github_issue(err_msg, exc_msg):
       settings.print_data_to_stdout("")
       raise SystemExit()
 
-  err_msg = err_msg[err_msg.find("\n"):]
+  err_msg = err_msg[err_msg.find(settings.END_LINE.LF):]
   request = _urllib.request.Request(url="https://api.github.com/search/issues?q=" + \
         _urllib.parse.quote("repo:commixproject/commix" + settings.SINGLE_WHITESPACE + str(bug_report))
         )
@@ -194,13 +206,13 @@ def create_github_issue(err_msg, exc_msg):
       if closed:
           warn_msg += " and resolved. Please update to the latest "
           warn_msg += "(dev) version from official GitHub repository at '" + settings.GIT_URL + "'"
-      warn_msg += ".\n"
+      warn_msg += "." + settings.END_LINE.LF
       settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
       return
   except:
     pass
 
-  data = {"title": str(bug_report), "body": "```" + str(err_msg) + "\n```\n```\n" + str(exc_msg) + "```"}
+  data = {"title": str(bug_report), "body": "```" + str(err_msg) + settings.END_LINE.LF + "```" + settings.END_LINE.LF + "```" + str(exc_msg) + "```"}
   request = _urllib.request.Request(url = "https://api.github.com/repos/commixproject/commix/issues",
                                 data = json.dumps(data).encode(),
                                 headers = {settings.AUTHORIZATION: "token " + base64.b64decode(settings.GITHUB_REPORT_OAUTH_TOKEN.encode(settings.DEFAULT_CODEC)).decode()}
@@ -212,12 +224,12 @@ def create_github_issue(err_msg, exc_msg):
 
   issue_url = re.search(r"https://github.com/commixproject/commix/issues/\d+", content.decode(settings.DEFAULT_CODEC) or "")
   if issue_url:
-    info_msg = "The created Github issue can been found at the address '" + str(issue_url.group(0)) + "'.\n"
+    info_msg = "The created Github issue can been found at the address '" + str(issue_url.group(0)) + "'." + settings.END_LINE.LF
     settings.print_data_to_stdout(settings.print_info_msg(info_msg))
   else:
     warn_msg = "Something went wrong while creating a Github issue."
     if settings.UNAUTHORIZED_ERROR in str(err):
-      warn_msg += " Please update to the latest revision.\n"
+      warn_msg += " Please update to the latest revision." + settings.END_LINE.LF
     settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
 
 """
@@ -279,15 +291,20 @@ def unhandled_exception():
     settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
     raise SystemExit()
 
+  elif "database disk image is malformed" in exc_msg:
+    exc_msg = "Local session file seems to be malformed. Please rerun with '--flush-session'."
+    settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+    raise SystemExit()
+
   elif all(_ in exc_msg for _ in ("No such file", "_'")):
-    err_msg = "Corrupted installation detected ('" + exc_msg.strip().split('\n')[-1] + "'). "
+    err_msg = "Corrupted installation detected ('" + exc_msg.strip().split(settings.END_LINE.LF)[-1] + "'). "
     err_msg += "You should retrieve the latest (dev) version from official GitHub "
     err_msg += "repository at '" + settings.GIT_URL + "'."
     settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
     raise SystemExit()
 
   elif "Invalid IPv6 URL" in exc_msg:
-    err_msg = "invalid URL ('" + exc_msg.strip().split('\n')[-1] + "')"
+    err_msg = "invalid URL ('" + exc_msg.strip().split(settings.END_LINE.LF)[-1] + "')"
     settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
     raise SystemExit()
 
@@ -326,6 +343,14 @@ def unhandled_exception():
     settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
     raise SystemExit()
 
+  elif any(_ in exc_msg for _ in ("tempfile.mkdtemp", "tempfile.mkstemp", "tempfile.py")):
+    err_msg = "Unable to write to the temporary directory. "
+    err_msg += "Please make sure your disk is not full and "
+    err_msg += "that you have sufficient permissions to "
+    err_msg += "create temporary files and/or directories."
+    settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+    raise SystemExit()
+
   else:
     err_msg = "Unhandled exception occurred in '" + settings.VERSION[1:] + "'. It is recommended to retry your "
     err_msg += "run with the latest (dev) version from official GitHub "
@@ -334,14 +359,45 @@ def unhandled_exception():
     err_msg += "with the following text and any other information required to "
     err_msg += "reproduce the bug. The "
     err_msg += "developers will try to reproduce the bug, fix it accordingly "
-    err_msg += "and get back to you.\n"
-    err_msg += "Commix version: " + settings.VERSION[1:] + "\n"
-    err_msg += "Python version: " + settings.PYTHON_VERSION + "\n"
-    err_msg += "Operating system: " + os.name + "\n"
-    err_msg += "Command line: " + re.sub(r".+?\bcommix\.py\b", "commix.py", " ".join(sys.argv)) + "\n"
+    err_msg += "and get back to you." + settings.END_LINE.LF
+    err_msg += settings.APPLICATION.capitalize() + " version: " + settings.VERSION[1:] + settings.END_LINE.LF
+    err_msg += "Python version: " + settings.PYTHON_VERSION + settings.END_LINE.LF
+    err_msg += "Operating system: " + os.name + settings.END_LINE.LF
+    err_msg += "Command line: " + re.sub(r".+?\bcommix\.py\b", "commix.py", " ".join(sys.argv)) + settings.END_LINE.LF
     err_msg = mask_sensitive_data(err_msg)
     exc_msg = re.sub(r'".+?[/\\](\w+\.py)', r"\"\g<1>", exc_msg)
-    settings.print_data_to_stdout(settings.print_critical_msg(err_msg + "\n" + exc_msg.rstrip()))
+    settings.print_data_to_stdout(settings.print_critical_msg(err_msg + settings.END_LINE.LF + exc_msg.rstrip()))
     create_github_issue(err_msg, exc_msg[:])
 
+"""
+Load a list of non-empty lines from a text file.
+"""
+def load_list_from_file(file_path, description="file"):
+
+  if not os.path.isfile(file_path):
+    err_msg = "The " + description + " '" + file_path + "' was not found."
+    settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+    raise SystemExit()
+
+  try:
+    with open(file_path, "r", encoding="utf-8") as f:
+      items = [line.strip() for line in f if line.strip()]
+  except IOError:
+    err_msg = "Cannot read the " + description + " '" + file_path + "'. "
+    err_msg += "Check if the file is corrupted or unreadable."
+    settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+    raise SystemExit()
+
+  if not items:
+    err_msg = "The " + description + " '" + file_path + "' is empty."
+    settings.print_data_to_stdout(settings.print_critical_msg(err_msg))
+    raise SystemExit()
+
+  if settings.VERBOSITY_LEVEL > 0:
+    debug_msg = "Loaded " + str(len(items)) + " entries from " + description + " '" + file_path + "'."
+    settings.print_data_to_stdout(settings.print_debug_msg(debug_msg))
+
+  return items
+
+
 # eof
\ No newline at end of file
