@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ import sqlite3
 from datetime import date
 from datetime import datetime
 from src.utils import menu
+from src.utils import common
 from src.utils import settings
 from src.utils import session_handler
 from src.core.injections.controller import checks
@@ -51,27 +52,36 @@ def path_creation(path):
 Logs filename creation.
 """
 def logs_filename_creation(url):
-  if menu.options.output_dir:
-    menu.options.output_dir = os.path.abspath(menu.options.output_dir)
-    if os.path.isdir(menu.options.output_dir):
-      output_dir = menu.options.output_dir
-      warn_msg = "Using '" + output_dir + "' for output directory."
-      settings.print_data_to_stdout(settings.print_warning_msg(warn_msg)) 
+  output_dir = menu.options.output_dir
+
+  if output_dir:
+    output_dir = os.path.abspath(output_dir)
+    if os.path.isdir(output_dir):
+      info_msg = "Using output directory '" + output_dir + "'."
+      settings.print_data_to_stdout(settings.print_info_msg(info_msg))
     else:
-      output_dir = tempfile.mkdtemp(prefix=settings.APPLICATION)
-      warn_msg = "Unable to create output directory '" + menu.options.output_dir + "'. "
-      warn_msg += "Using temporary directory '" + output_dir + "' instead."
-      settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
+      try:
+        os.makedirs(output_dir, exist_ok=True)
+        info_msg = "Created missing output directory '" + output_dir + "'."
+        settings.print_data_to_stdout(settings.print_info_msg(info_msg))
+      except OSError:
+        error_msg = "Unable to create missing output directory '" + output_dir + "'."
+        settings.print_data_to_stdout(settings.print_error_msg(error_msg))
+        try:
+          output_dir = tempfile.mkdtemp(prefix=settings.APPLICATION)
+          warn_msg = "Using temporary output directory '" + output_dir + "' instead."
+          settings.print_data_to_stdout(settings.print_warning_msg(warn_msg))
+        except (OSError, RuntimeError):
+          common.unhandled_exception()
   else:
     output_dir = settings.OUTPUT_DIR
-    path_creation(os.path.dirname(settings.OUTPUT_DIR))
+    path_creation(os.path.dirname(output_dir))
 
-  if not output_dir.endswith("/"):
-    output_dir = output_dir + "/"
+  # Ensure path ends with OS-specific separator
+  output_dir = os.path.join(output_dir, '')
 
-  # The logs filename construction.
-  filename = create_log_file(url, output_dir)
-  return filename
+  # Create the logs filename
+  return create_log_file(url, output_dir)
 
 """
 Create log files
@@ -104,14 +114,14 @@ def create_log_file(url, output_dir):
   # The logs filename construction.
   filename = logs_path + settings.OUTPUT_FILE
   try:
-    with open(filename, 'a') as output_file:
+    with open(filename, 'a', encoding=settings.DEFAULT_CODEC) as output_file:
       if not menu.options.no_logging:
-        output_file.write("\n" + "=" * 37)
-        output_file.write("\n" + "| Started in " + \
+        output_file.write(settings.END_LINE.LF + "=" * 37)
+        output_file.write(settings.END_LINE.LF + "| Started in " + \
           str(date.today()) + \
           " at " + datetime.now().strftime("%H:%M:%S") + " |")
-        output_file.write("\n" + "=" * 37)
-        output_file.write("\n" + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Tested URL : " + url)
+        output_file.write(settings.END_LINE.LF + "=" * 37)
+        output_file.write(settings.END_LINE.LF + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Tested URL : " + url)
   except IOError as err_msg:
     try:
       error_msg = str(err_msg.args[0]).split("] ")[1] + "."
@@ -132,10 +142,10 @@ def add_type_and_technique(export_injection_info, filename, injection_type, tech
 
   if export_injection_info == False:
     settings.SHOW_LOGS_MSG = True
-    with open(filename, 'a') as output_file:
+    with open(filename, 'a', encoding=settings.DEFAULT_CODEC) as output_file:
       if not menu.options.no_logging:
-        output_file.write("\n" + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Type: " + injection_type.title())
-        output_file.write("\n" + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Technique: " + technique.title())
+        output_file.write(settings.END_LINE.LF + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Type: " + injection_type.title())
+        output_file.write(settings.END_LINE.LF + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Technique: " + technique.title())
       export_injection_info = True
   return export_injection_info
 
@@ -143,27 +153,27 @@ def add_type_and_technique(export_injection_info, filename, injection_type, tech
 Add the vulnerable parameter in log files.
 """
 def add_parameter(vp_flag, filename, the_type, header_name, http_request_method, vuln_parameter, payload):
-  with open(filename, 'a') as output_file:
+  with open(filename, 'a', encoding=settings.DEFAULT_CODEC) as output_file:
     if not menu.options.no_logging:
       if header_name[1:] == settings.COOKIE.lower():
         header_name = " ("+ header_name[1:] + ") " + vuln_parameter
       if header_name[1:] == "":
         header_name = " ("+ http_request_method + ") " + vuln_parameter
-      output_file.write("\n" + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + the_type[1:].title() + ": " + header_name[1:])
+      output_file.write(settings.END_LINE.LF + re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + the_type[1:].title() + ": " + header_name[1:])
       vp_flag = False
-      output_file.write("\n")
+      output_file.write(settings.END_LINE.LF)
 
 
 """
 Add any payload in log files.
 """
 def update_payload(filename, counter, payload):
-  with open(filename, 'a') as output_file:
+  with open(filename, 'a', encoding=settings.DEFAULT_CODEC) as output_file:
     if not menu.options.no_logging:
-      if "\n" in payload:
-        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Used payload: " + re.sub("%20", settings.SINGLE_WHITESPACE, _urllib.parse.unquote_plus(payload.replace("\n", "\\n"))) + "\n")
+      if settings.END_LINE.LF in payload:
+        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Used payload: " + re.sub("%20", settings.SINGLE_WHITESPACE, _urllib.parse.unquote_plus(payload.replace(settings.END_LINE.LF, settings.END_LINE.ESCAPED_LF))) + settings.END_LINE.LF)
       else:
-        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Used payload: " + payload.replace("%20", settings.SINGLE_WHITESPACE) + "\n")
+        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Used payload: " + payload.replace("%20", settings.SINGLE_WHITESPACE) + settings.END_LINE.LF)
 
 """
 Add any executed command and
@@ -171,11 +181,11 @@ execution output result in log files.
 """
 def executed_command(filename, cmd, output):
   try:
-    with open(filename, 'a') as output_file:
+    with open(filename, 'a', encoding=settings.DEFAULT_CODEC) as output_file:
       if not menu.options.no_logging:
-        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Executed command: " +  cmd + "\n")
-        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_SIGN) + "Execution output: " + output.encode(settings.DEFAULT_CODEC).decode() + "\n")
-  except TypeError:
+        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_BOLD_SIGN) + "Executed command: " +  cmd + settings.END_LINE.LF)
+        output_file.write(re.compile(re.compile(settings.ANSI_COLOR_REMOVAL)).sub("",settings.INFO_SIGN) + "Execution output: " + str(output.encode(settings.DEFAULT_CODEC).decode()) + settings.END_LINE.LF)
+  except:
     pass
 
 """
