@@ -3,7 +3,7 @@
 
 """
 This file is part of Commix Project (https://commixproject.com).
-Copyright (c) 2014-2024 Anastasios Stasinopoulos (@ancst).
+Copyright (c) 2014-2025 Anastasios Stasinopoulos (@ancst).
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -86,7 +86,7 @@ TRAFFIC_SIGN = HTTP_CONTENT_SIGN = ""
 ABORTION_SIGN = ERROR_SIGN
 DEBUG_SIGN = "[" + Back.BLUE + Fore.WHITE + "debug" + Style.RESET_ALL + "] "
 DEBUG_BOLD_SIGN = "[" + Back.BLUE + Style.BRIGHT + Fore.WHITE + "debug" + Style.RESET_ALL + "] " + Style.BRIGHT
-CHECK_SIGN = DEBUG_SIGN + "Checking for a valid pair of HTTP authentication credentials: "
+CHECK_SIGN = DEBUG_SIGN + "Checking for a valid pair of authentication credentials: "
 OS_SHELL_TITLE = Style.BRIGHT + "Pseudo-Terminal Shell (type '?' for available options)" + Style.RESET_ALL
 OS_SHELL = """commix(""" + Style.BRIGHT + Fore.RED + """os_shell""" + Style.RESET_ALL + """) > """
 REVERSE_TCP_SHELL = """commix(""" + Style.BRIGHT + Fore.RED + """reverse_tcp""" + Style.RESET_ALL + """) > """
@@ -222,7 +222,6 @@ def print_data_to_stdout(data):
   sys.stdout.write(data)
   sys.stdout.flush()
 
-
 """
 argv input errors
 """
@@ -261,18 +260,18 @@ APPLICATION = "commix"
 DESCRIPTION_FULL = "Automated All-in-One OS Command Injection Exploitation Tool"
 DESCRIPTION = "The command injection exploiter"
 AUTHOR  = "Anastasios Stasinopoulos"
-VERSION_NUM = "4.0"
-REVISION = "121"
+VERSION_NUM = "4.1"
+REVISION = "126"
 STABLE_RELEASE = True
 VERSION = "v"
 if STABLE_RELEASE:
-  VERSION = VERSION + VERSION_NUM + "-stable"
+  VERSION = VERSION + VERSION_NUM
   COLOR_VERSION = Style.BRIGHT + Style.UNDERLINE + Fore.WHITE + VERSION + Style.RESET_ALL
 else:
-  VERSION = VERSION + VERSION_NUM + "-dev#" + REVISION
+  VERSION = VERSION + VERSION_NUM + ".dev" + REVISION
   COLOR_VERSION = Style.UNDERLINE + Fore.WHITE + VERSION + Style.RESET_ALL
 
-YEAR = "2014-2024"
+YEAR = "2014-2025"
 AUTHOR_X_ACCOUNT = "@ancst"
 APPLICATION_URL = "https://commixproject.com"
 APPLICATION_X_ACCOUNT = "@commixproject"
@@ -287,6 +286,11 @@ LEGAL_DISCLAIMER_MSG = "Usage of " + APPLICATION + " for attacking targets witho
 
 # Random string generator
 RANDOM_STRING_GENERATOR = ''.join(random.choice(string.ascii_uppercase + string.digits + string.ascii_lowercase) for _ in range(10))
+# Random variable name
+RANDOM_VAR_GENERATOR = ''.join(random.choice(string.ascii_uppercase) for _ in range(3))
+
+# Path to text resources folder
+TXT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'txt'))
 
 START_TIME = time.time()
 
@@ -317,6 +321,11 @@ INJECT_TAG_REGEX = r"(?i)INJECT[_]?HERE"
 VALUE_BOUNDARIES = r'[\\/](.+?)[\\/]'
 INJECT_INSIDE_BOUNDARIES = None
 
+# Safe characters to keep unescaped in URL paths
+SAFE_PATH = "*%/"
+# Safe characters to keep unescaped in query strings
+SAFE_QUERY = SAFE_PATH + "=?&"
+
 # Default (windows) target host's python interpreter
 WIN_PYTHON_INTERPRETER = "python.exe"
 WIN_CUSTOM_PYTHON_INTERPRETER = "C:\\Python27\\python.exe"
@@ -329,6 +338,9 @@ USER_DEFINED_PYTHON_INTERPRETER = False
 
 CMD_NUL = ""
 
+CMD_SUB_PREFIX = "$("
+CMD_SUB_SUFFIX = ")"
+
 # Maybe a WAF/IPS protection.
 WAF_CHECK_PAYLOAD = "cat /etc/passwd|uname&&ping -c3 localhost;ls ../"
 WAF_ENABLED = False
@@ -340,14 +352,16 @@ class HEURISTIC_TEST(object):
 RAND_A = random.randint(1,10000)
 RAND_B = random.randint(1,10000)
 CALC_STRING = str(RAND_A) + " %2B " + str(RAND_B)
-BASIC_STRING = "(" + CALC_STRING + ")"
-BASIC_COMMAND_INJECTION_PAYLOADS = [";echo $(" + BASIC_STRING + ")%26echo $(" + BASIC_STRING + ")|echo $(" + BASIC_STRING + ")" + RANDOM_STRING_GENERATOR ,
-                                   "|set /a " + BASIC_STRING + "%26set /a " + BASIC_STRING
-                                   ]
+BASIC_STRING = ""
+BASIC_COMMAND_INJECTION_PAYLOADS = []
 ALTER_SHELL_BASIC_STRING = " -c \"print(int(" + CALC_STRING + "))\""
-ALTER_SHELL_BASIC_COMMAND_INJECTION_PAYLOADS = [";echo $(" + LINUX_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + ")%26echo $(" + LINUX_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + ")|echo $(" + LINUX_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + ")",
-                                   "|for /f \"tokens=*\" %i in ('cmd /c " + WIN_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + "') do @set /p=%i" + CMD_NUL + " &for /f \"tokens=*\" %i in ('cmd /c " + WIN_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + "') do @set /p=%i" + CMD_NUL
-                                   ]
+ALTER_SHELL_BASIC_COMMAND_INJECTION_PAYLOADS = [";echo " + CMD_SUB_PREFIX + LINUX_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + CMD_SUB_SUFFIX + 
+                                                "%26echo " + CMD_SUB_PREFIX + LINUX_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + CMD_SUB_SUFFIX + 
+                                                "|echo " + CMD_SUB_PREFIX + LINUX_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + CMD_SUB_SUFFIX + 
+                                                RANDOM_STRING_GENERATOR,
+                                                "|for /f \"tokens=*\" %i in ('cmd /c " + WIN_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + "') do @set /p=%i" + CMD_NUL + 
+                                                " &for /f \"tokens=*\" %i in ('cmd /c " + WIN_PYTHON_INTERPRETER + ALTER_SHELL_BASIC_STRING + "') do @set /p=%i" + CMD_NUL
+                                                ]
 BASIC_COMMAND_INJECTION_RESULT = str(RAND_A + RAND_B)
 IDENTIFIED_COMMAND_INJECTION = False
 
@@ -402,12 +416,13 @@ class INJECTION_MARKER_LOCATION(object):
   HTTP_HEADERS = False
   CUSTOM_HTTP_HEADERS = False
 
-SKIP_NON_CUSTOM = None
+SKIP_NON_CUSTOM_PARAMS = None
 
-# Testable parameter(s) - comma separated.
 TESTABLE_PARAMETERS_LIST = []
 TESTABLE_PARAMETERS = None
 NOT_TESTABLE_PARAMETERS = True
+TESTED_PARAMETERS_LIST = []
+METHODS_WITH_NON_LISTED_PARAMS = []
 
 # Skip testing for given parameter(s) - comma separated.
 SKIP_PARAMETER = ""
@@ -423,7 +438,7 @@ class OS(object):
 TARGET_OS = OS.UNIX
 
 IDENTIFIED_TARGET_OS = False
-IGNORE_IDENTIFIED_OS = None
+IGNORE_IDENTIFIED_TARGET_OS = None
 
 # Verbosity level (0-4, Default: 0)
 VERBOSITY_LEVEL = 0
@@ -442,13 +457,17 @@ WAF_DETECTION_PHASE = False
 DETECTION_PHASE = False
 EXPLOITATION_PHASE = False
 
+# Prevent the shell from interpreting the redirection operators.
+NO_OUTPUT = ">/dev/null 2>&1"
+
 # Exploitation techniques states
 CLASSIC_STATE = False
 EVAL_BASED_STATE = False
 TIME_BASED_STATE = False
 FILE_BASED_STATE = False
 TEMPFILE_BASED_STATE = False
-TIME_RELATIVE_ATTACK = False
+TIME_RELATED_ATTACK = False
+TIME_RELATED_ATTACK_WARNING = False
 
 # Stored applied techniques
 SESSION_APPLIED_TECHNIQUES = ""
@@ -489,6 +508,8 @@ MAX_CONNECTION_TOTAL_SIZE = 100 * 1024 * 1024
 # Slow target response.
 SLOW_TARGET_RESPONSE = 3
 
+RESPONSE_DELAYS = False
+
 # The testable parameter.
 TESTABLE_PARAMETER = ""
 
@@ -586,6 +607,7 @@ TMP_PATH = ""
 WEB_ROOT = ""
 DEFAULT_WEB_ROOT = ""
 CUSTOM_WEB_ROOT = False
+CUSTOM_FILENAME = ""
 
 # Counting the total of HTTP(S) requests
 TOTAL_OF_REQUESTS = 0
@@ -698,51 +720,6 @@ class INJECTION_TECHNIQUE(object):
 USER_APPLIED_TECHNIQUE = False
 SKIP_TECHNIQUES = False
 
-# User Agent List
-USER_AGENT_LIST = [
-        # Opera
-        "Opera/8.0 (X11; Linux i686; U; en)",
-        "Opera/9.01 (X11; FreeBSD 6 i386; U; en)"
-        "Opera/8.51 (FreeBSD 5.1; U; en)",
-        "Opera/8.51 (Macintosh; PPC Mac OS X; U; de)",
-        "Opera/9.00 (Macintosh; PPC Mac OS X; U; es)",
-        "Opera/12.80 (Windows NT 5.1; U; en) Presto/2.10.289 Version/12.02",
-        # Mozilla Firefox
-        "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:21.0) Gecko/20131331 Firefox/31.0",
-        "Mozilla/5.0 (Windows; U; Windows NT 5.1; fr; rv:1.8.1.13) Gecko/20080311 Firefox/2.0.0.13 (.NET CLR 3.0.04506.31)",
-        "Mozilla/5.0 (X11; Linux i686; rv:21.0) Gecko/20100101 Firefox/21.0",
-        "Mozilla/5.0 (MSIE 7.0; Macintosh; U; SunOS; X11; gu; SV1; InfoPath.2; .NET CLR 3.0.04506.31; .NET CLR 3.0.04506.648)",
-        "Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; AS; rv:11.0) like Gecko",
-        "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.9 Safari/536.5",
-        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.6; rv:9.0) Gecko/20100101 Firefox/9.0",
-        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/534.57.2 (KHTML, like Gecko) Version/4.0.5 Safari/531.22.7",
-        "Mozilla/5.0 (Windows NT 5.1; rv:31.0) Gecko/20100101 Firefox/31.0",
-        "Mozilla/5.0 (X11; U; Linux i686; zh-CN; rv:1.9.1.6) Gecko/20091216 Fedora/3.5.6-1.fc11 Firefox/3.5.6 GTB6",
-        "Mozilla/5.0 (X11; U; Linux i686 (x86_64); en-US; rv:1.9.1b3) Gecko/20090315 Firefox/3.1b3",
-        "Mozilla/5.0 (Windows NT 6.1; WOW64; rv:21.0) Gecko/20131401 Firefox/31.0",
-        "Mozilla/5.0 (Windows NT 5.1) AppleWebKit/534.34 (KHTML, like Gecko) Dooble/1.40 Safari/534.34",
-        # Oldies
-        "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0; de) Opera 8.0",
-        "Mozilla/4.0 (compatible; MSIE 7.0b; Windows NT 6.0)",
-        "Mozilla/4.0 (compatible; MSIE 7.0b; Windows NT 5.1; .NET CLR 1.1.4322; InfoPath.1; .NET CLR 2.0.50727)",
-        "mozilla/3.0 (Windows NT 6.1; rv:2.0.1) Gecko/20100101 Firefox/5.0.1",
-]
-
-# Mobile User Agents
-MOBILE_USER_AGENT_LIST = [
-        "Mozilla/5.0 (BB10; Kbd) AppleWebKit/537.35+ (KHTML, like Gecko) Version/10.3.3.2205 Mobile Safari/537.35+",
-        "Mozilla/5.0 (Linux; Android 7.0; SM-G931V Build/NRD90M) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3171.125 Mobile Safari/537.36",
-        "Mozilla/4.0 (compatible; MSIE 4.01; Windows CE; PPC; 240x320; HP iPAQ h6310)",
-        "Mozilla/5.0 (Linux; Android 8.0.0; HTC 10 Build/OPR1.170623.027) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/69.0.3497.100 Mobile Safari/537.36",
-        "Mozilla/5.0 (Linux; Android 4.4.4; HUAWEI H891L Build/HuaweiH891L) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/33.0.0.0 Mobile Safari/537.36",
-        "Mozilla/5.0 (iPhone; CPU iPhone OS 11_0 like Mac OS X) AppleWebKit/604.1.38 (KHTML, like Gecko) Version/11.0 Mobile/15A372 Safari/604.1",
-        "Mozilla/5.0 (Windows Phone 10.0; Android 6.0.1; Microsoft; Lumia 950) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/52.0.2743.116 Mobile Safari/537.36 Edge/15.14977",
-        "Mozilla/5.0 (Linux; Android 4.1.1; Nexus 7 Build/JRO03D) AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.166 Safari/535.19",
-        "Mozilla/5.0 (SymbianOS/9.4; Series60/5.0 NokiaN97-1/10.0.012; Profile/MIDP-2.1 Configuration/CLDC-1.1; en-us) AppleWebKit/525 (KHTML, like Gecko) WicKed/7.1.12344",
-        "Mozilla/5.0 (Linux; Android 8.0.0; Pixel Build/OPR3.170623.013) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.111 Mobile Safari/537.36",
-        "Mozilla/5.0 (Linux; U; Android 4.4.4; en-gb; MI 3W Build/KTU84P) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/39.0.0.0 Mobile Safari/537.36 XiaoMi/MiuiBrowser/2.1.1",
-]
-
 # Default Scheme
 SCHEME = ""
 
@@ -798,14 +775,17 @@ SET_OPTIONS = [
         "URIPATH",
 ]
 
-# Cookie delimiter
-COOKIE_DELIMITER = ";"
+# Delimiter used to separate individual cookies in the Cookie HTTP header
+COOKIE_PARAM_DELIMITER = ";"
 
 # Split parameter value
 PARAMETER_SPLITTING_REGEX = ","
 
-# Cookie delimiter
-PARAMETER_DELIMITER = "&"
+# Delimiter used to separate parameters in POST request body
+POST_DATA_PARAM_DELIMITER = "&"
+
+# Delimiter used to separate query parameters in a URL
+URL_PARAM_DELIMITER = "&"
 
 DEFAULT_CODEC = "utf8"
 
@@ -999,6 +979,7 @@ XML_RECOGNITION_REGEX = r'(?s)\A\s*<[^>]+>(.+>)?\s*\Z'
 
 # JSON Data
 IS_JSON = False
+IS_VALID_JSON = False
 
 # Infixes used for automatic recognition of parameters carrying anti-CSRF tokens
 CSRF_TOKEN_PARAMETER_INFIXES = ("csrf", "xsrf", "token")
@@ -1062,20 +1043,31 @@ SRVPORT = 8080
 SESSION_FILE = ""
 LOAD_SESSION = None
 
-# Define the default credentials files
-USERNAMES_TXT_FILE = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'txt')) + "/" + "default_usernames.txt"
-PASSWORDS_TXT_FILE = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'txt')) + "/" + "default_passwords.txt"
+# Path to file containing desktop/browser User-Agent strings
+USER_AGENT_LIST = os.path.join(TXT_DIR, "user-agents.txt")
+
+# Path to file containing mobile User-Agent strings
+MOBILE_USER_AGENT_LIST = os.path.join(TXT_DIR, "mobile-user-agents.txt")
+
+# Path to file with default username values
+USERNAMES_TXT_FILE = os.path.join(TXT_DIR, "default_usernames.txt")
+
+# Path to file with default password values
+PASSWORDS_TXT_FILE = os.path.join(TXT_DIR, "default_passwords.txt")
+
+# Path to file with known CGI scripts/pages potentially vulnerable to Shellshock
+CGI_SCRIPTS = os.path.join(TXT_DIR, "shocker-cgi_list.txt")
 
 REQUIRED_AUTHENTICATION = False
 
 INJECTED_HTTP_HEADER = False
 INJECTION_CHECKER = False
 
-# List of pages / scripts potentially vulnerable to Shellshock
-CGI_SCRIPTS = os.path.abspath(os.path.join(os.path.dirname(__file__), '..', 'txt')) + "/" + "shocker-cgi_list.txt"
+INSTALL_DIR = "/usr/share/"
+WRAPPER_PATH = "/usr/bin/"
 
 # Metasploit Framework Path
-METASPLOIT_PATH = "/usr/share/metasploit-framework/"
+METASPLOIT_PATH = INSTALL_DIR + "/metasploit-framework/"
 
 # Supported HTTP Authentication types
 class AUTH_TYPE(object):
@@ -1087,6 +1079,9 @@ RAW_HTTP_HEADERS = ""
 
 USER_APPLIED_TAMPER = ""
 
+# Tamper payload modification letters
+TAMPER_MODIFICATION_LETTERS = r'([e-zE-Z])'
+
 # Tamper scripts dict
 TAMPER_SCRIPTS = {
                   "space2ifs": False,
@@ -1107,9 +1102,10 @@ TAMPER_SCRIPTS = {
                   "dollaratsigns": False,
                   "printf2echo": False,
                   "uninitializedvariable": False,
-                  "slash2env":False,
-                  "backticks":False,
-                  "rev":False
+                  "slash2env": False,
+                  "backticks": False,
+                  "randomcase": False,
+                  "rev": False
                  }
 
 UNIX_NOT_SUPPORTED_TAMPER_SCRIPTS = [
@@ -1128,6 +1124,7 @@ WIN_NOT_SUPPORTED_TAMPER_SCRIPTS = [
                   "printf2echo",
                   "space2ifs",
                   "uninitializedvariable",
+                  "randomcase",
                   "rev"
 ]
 
@@ -1143,15 +1140,23 @@ EVAL_NOT_SUPPORTED_TAMPER_SCRIPTS = [
                   "uninitializedvariable"
 ]
 
+TIME_RELATED_TAMPER_SCRIPTS = [
+                  "sleep2usleep",
+                  "sleep2timeout"
+]
+
 IGNORE_TAMPER_TRANSFORMATION = [
                   "IFS",
                   "if",
                   "then",
                   "else",
                   "fi",
-                  "str",
                   "cmd",
-                  "char"
+                  "%0d",
+                  "PATH%%u*",
+                  RANDOM_VAR_GENERATOR,
+                  RANDOM_VAR_GENERATOR + "1",
+                  RANDOM_VAR_GENERATOR + "2"
 ]
 
 # HTTP Errors
@@ -1186,6 +1191,7 @@ class END_LINE:
   CR = "\r"
   LF = "\n"
   CRLF = "\r\n"
+  ESCAPED_LF = "\\n"
 
 # List of end lines
 END_LINES_LIST = [attr for attr in dir(END_LINE) if not callable(getattr(END_LINE, attr)) and not attr.startswith("__")]
@@ -1267,8 +1273,27 @@ NAGGING_DAYS = 31
 
 TARGET_URL = ""
 DOC_ROOT_TARGET_MARK = "%TARGET%"
-WINDOWS_DEFAULT_DOC_ROOTS = ["C:\\\\Inetpub\\wwwroot\\", "C:\\\\Inetpub\\wwwroot\\", "C:\\\\xampp\\htdocs\\", "C:\\\\wamp\\www\\"]
-LINUX_DEFAULT_DOC_ROOTS = ["/var/www/" + DOC_ROOT_TARGET_MARK + "/public_html/", "/var/www/" + DOC_ROOT_TARGET_MARK + "/", "/usr/local/apache2/htdocs/", "/usr/local/www/data/", "/usr/share/nginx/", "/var/apache2/htdocs/", "/var/www/nginx-default/", "/srv/www/htdocs/"]  # Reference: https://wiki.apache.org/httpd/DistrosDefaultLayout
+
+# Windows common document roots
+WINDOWS_DEFAULT_DOC_ROOTS = [
+                  "C:\\Inetpub\\wwwroot\\",    # IIS default
+                  "C:\\xampp\\htdocs\\",       # XAMPP default
+                  "C:\\wamp\\www\\",           # WAMP default
+                  "C:\\laragon\\www\\",        # Laragon default
+                  "D:\\Inetpub\\wwwroot\\",    # IIS on D: drive (less common)
+]
+# Linux common document roots
+LINUX_DEFAULT_DOC_ROOTS = [
+                  "/var/www/html/",                                      # Debian/Ubuntu Apache default
+                  "/var/www/" + DOC_ROOT_TARGET_MARK + "/public_html/",  # Older Debian/Ubuntu with custom doc root
+                  "/var/www/" + DOC_ROOT_TARGET_MARK + "/",              # Alternative Debian/Ubuntu
+                  "/usr/share/nginx/html/",                              # Nginx default
+                  "/usr/local/apache2/htdocs/",                          # Apache default (source build)
+                  "/usr/local/www/data/",                                # BSD-style
+                  "/var/apache2/htdocs/",                                # Older Apache distros
+                  "/var/www/nginx-default/",                             # Nginx variation
+                  "/srv/www/htdocs/"                                     # SUSE/Fedora style
+]
 
 DEFINED_WEBROOT = RECHECK_FILE_FOR_EXTRACTION = False
 
@@ -1371,5 +1396,4 @@ ALERT = False
 USE_PCRE_E_MODIFIER = None
 PCRE_MODIFIER = "/e"
 
-
 # eof
